# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    p.county("Harju", "")
    p.town("Tallinn", "")
    p.town("Loksa", "")
    p.municipality("Vasalemma", "")
    p.smallborough("Rummu", "")
    p.village("Veskiküla", "")
    p.smallborough("Ämari", "")
    p.village("Lemmaru", "76107")

    p.municipality("Nissi", "")
    p.smallborough("Turba", "")
    p.village("Lehetu", "")
    p.village("Madila", "")
    p.smallborough("Riisipere", "")
    p.village("Kivitammi", "76207")
    p.village("Mustu", "76216")
    p.village("Lepaste", "76217")
    p.village("Tabara", "")
    p.village("Viruküla", "76206")
    p.village("Odulemma", "76210")
    p.village("Ellamaa", "76203")
    p.village("Jaanika", "76211")
    p.village("Aude", "76209")
    p.village("Rehemäe", "76218")
    p.village("Ürjaste", "76214")
    p.village("Siimika", "76208")
    p.village("Nurme", "76215")
    p.village("Vilumäe", "76212")
    p.village("Munalaskme", "76318")

    p.municipality("Saku", "")
    p.village("Tänassilma", "")
    p.village("Üksnurme", "")
    p.village("Rahula", "")
    p.village("Roobuka", "")
    p.village("Jälgimäe", "")
    p.village("Kirdalu", "")
    p.village("Kasemetsa", "")
    p.village("Männiku", "")
    p.village("Tagadi", "")
    p.village("Kurtna", "")
    p.village("Metsanurme", "")
    p.smallborough("Kiisa", "")
    p.village("Juuliku", "")
    p.village("Tammejärve", "")
    p.village("Kanama", "")
    p.village("Saustinõmme", "")
    p.village("Tõdva", "")
    p.village("Lokuti", "")
    p.village("Tammemäe", "75509")
    p.village("Kajamaa", "75504")
    p.village("Sookaera-Metsanurga", "75515")

    p.town("Saue", "")
    p.smallborough("Laagri", "")
    p.village("Aila", "")
    p.village("Alliku", "")
    p.village("Ääsmäe", "")
    p.village("Vatsla", "")
    p.village("Hüüru", "")
    p.village("Vanamõisa", "")
    p.village("Jõgisoo", "")
    p.village("Püha", "")
    p.village("Maidla", "")
    p.village("Valingu", "")
    p.village("Koppelmaa", "")
    p.village("Tuula", "")
    p.village("Pällu", "")
    p.village("Kiia", "")
    p.village("Tagametsa", "76409")
    p.village("Pärinurme", "76408")
    p.village("Koidu", "76418")

    p.municipality("Viimsi", "")
    p.village("Püünsi", "")
    p.village("Pringi", "")
    p.village("Muuga", "")
    p.smallborough("Haabneeme", "")
    p.village("Laiaküla", "")
    p.village("Lubja", "")
    p.village("Rohuneeme", "")
    p.village("Pärnamäe", "")
    p.village("Tammneeme", "")
    p.village("Leppneeme", "")
    p.village("Metsakasti", "")
    p.village("Randvere", "")
    p.village("Miiduranna", "")
    p.village("Kelvingi", "")
    p.village("Äigrumäe", "")
    p.village("Kelnase", "")
    p.village("Lõunaküla/Storbyn", "74022")
    p.village("Tagaküla/Bakbyn", "74023")
    p.village("Lääneotsa", "74007")
    p.village("Väikeheinamaa/Lillängin", "74024")
    p.village("Idaotsa", "74005")

    p.municipality("Raasiku", "")
    p.smallborough("Aruküla", "")
    p.village("Kurgla", "")
    p.village("Kalesi", "")
    p.village("Kiviloo", "")
    p.village("Perila", "")
    p.village("Peningi", "")
    p.village("Igavere", "")
    p.village("Kulli", "")
    p.village("Rätla", "75216")
    p.village("Järsi", "75204")
    p.village("Pikavere", "75202")
    p.village("Härma", "75214")
    p.village("Tõhelgi", "75223")
    p.village("Mallavere", "75210")

    p.municipality("Jõelähtme", "")
    p.smallborough("Loo", "")
    p.village("Jägala", "")
    p.village("Kaberneeme", "")
    p.village("Liivamäe", "")
    p.village("Neeme", "")
    p.village("Manniva", "")
    p.village("Uusküla", "")
    p.village("Ülgase", "")
    p.village("Ihasalu", "")
    p.village("Kallavere", "")
    p.smallborough("Kostivere", "")
    p.village("Iru", "")
    p.village("Haljava", "")
    p.village("Koogi", "")
    p.village("Saviranna", "")
    p.village("Saha", "")
    p.village("Rebala", "")
    p.village("Ruu", "")
    p.village("Koipsi", "74215")
    p.village("Rammu", "74227")
    p.village("Aruaru", "75225")
    p.village("Võerdla", "74221")
    p.village("Vandjala", "74229")
    p.village("Sambu", "75222")
    p.village("Rohusi", "74219")
    p.village("Kullamäe", "74218")
    p.village("Kostiranna", "74225")
    p.village("Parasmäe", "74230")
    p.village("Nehatu", "74208")
    p.village("Koila", "74214")

    p.town("Maardu", "")
    p.municipality("Rae", "")
    p.smallborough("Vaida", "")
    p.smallborough("Jüri", "")
    p.village("Patika", "")
    p.village("Lehmja", "")
    p.village("Vaskjala", "")
    p.village("Järveküla", "")
    p.village("Aaviku", "")
    p.village("Pajupea", "")
    p.village("Tuulevälja", "")
    p.smallborough("Peetri", "")
    p.smallborough("Lagedi", "")
    p.village("Karla", "")
    p.village("Pildiküla", "")
    p.village("Soodevahe", "")
    p.village("Kadaka", "")
    p.village("Ülejõe", "")
    p.village("Suuresta", "")
    p.smallborough("Assaku", "")
    p.village("Veskitaguse", "")
    p.village("Suursoo", "")
    p.village("Veneküla", "")
    p.village("Kurna", "")
    p.village("Kopli", "")
    p.village("Urvaste", "")
    p.village("Salu", "")
    p.village("Limu", "")
    p.village("Vaidasoo", "")
    p.village("Seli", "75311")
    p.village("Kautjala", "75315")
    p.village("Aruvalla", "75320")

    p.municipality("Harku", "")
    p.smallborough("Tabasalu", "")
    p.village("Adra", "")
    p.village("Liikva", "")
    p.village("Tiskre", "")
    p.village("Naage", "")
    p.village("Ilmandu", "")
    p.village("Muraste", "")
    p.village("Suurupi", "")
    p.village("Harkujärve", "")
    p.village("Rannamõisa", "")
    p.village("Viti", "")
    p.village("Türisalu", "")
    p.village("Kumna", "")
    p.village("Laabi", "")
    p.village("Tutermaa", "")
    p.village("Sõrve", "")
    p.village("Kütke", "")
    p.village("Vaila", "")
    p.village("Vääna", "")
    p.village("Vääna-Jõesuu", "")
    p.village("Vahi", "")
    p.village("Humala", "76707")

    p.municipality("Keila", "")
    p.village("Kloogaranna", "")
    p.smallborough("Klooga", "")
    p.village("Lehola", "")
    p.village("Maeru", "")
    p.village("Laulasmaa", "")
    p.village("Ohtu", "")
    p.village("Kulna", "")
    p.village("Illurma", "")
    p.village("Tuulna", "")
    p.village("Meremõisa", "")
    p.village("Valkse", "")
    p.smallborough("Keila-Joa", "")
    p.smallborough("Karjaküla", "")
    p.village("Lohusalu", "")
    p.village("Käesalu", "")
    p.village("Niitvälja", "")
    p.village("Tõmmiku", "76619")
    p.village("Laoküla", "76714")
    p.village("Nahkjala", "76104")
    p.village("Põllküla", "76712")
    p.village("Keelva", "76622")

    p.municipality("Anija", "")
    p.town("Kehra", "")
    p.village("Lükati", "")
    p.village("Alavere", "")
    p.village("Mustjõe", "")
    p.village("Pillapalu", "")
    p.village("Lehtmetsa", "")
    p.village("Kuusemäe", "")
    p.village("Soodla", "")
    p.village("Parila", "75221")
    p.village("Aavere", "74417")
    p.village("Paasiku", "74314")
    p.village("Salumetsa", "74312")
    p.village("Kihmla", "75219")
    p.village("Looküla", "74311")
    p.village("Rasivere", "74403")
    p.village("Voose", "74410")
    p.village("Linnakse", "75220")
    p.village("Arava", "74405")
    p.village("Partsaare", "74415")
    p.village("Uuearu", "74407")
    p.village("Salumäe", "75226")
    p.village("Kaunissaare", "74309")
    p.village("Vetla", "74408")
    p.village("Pikva", "")
    p.village("Raudoja", "74416")
    p.village("Rooküla", "74404")
    p.village("Härmakosu", "74412")
    p.village("Lilli", "74414")

    p.municipality("Kiili", "")
    p.smallborough("Luige", "")
    p.village("Sausti", "")
    p.smallborough("Kangru", "")
    p.village("Nabala", "")
    p.village("Sookaera", "")
    p.village("Vaela", "")
    p.village("Lähtse", "")
    p.village("Mõisaküla", "")
    p.village("Sõgula", "75410")
    p.village("Kurevere", "75405")
    p.village("Paekna", "75408")
    p.village("Arusta", "75402")
    p.village("Piissoo", "75414")

    p.town("Paldiski", "")
    p.municipality("Kose", "")
    p.smallborough("Kose-Uuemõisa", "")
    p.village("Oru", "")
    p.village("Tade", "")
    p.village("Liiva", "")
    p.smallborough("Ravila", "")
    p.village("Tuhala", "")
    p.village("Saula", "")
    p.village("Ahisilla", "")
    p.village("Krei", "")
    p.village("Palvere", "")
    p.village("Vardja", "")
    p.village("Nõmbra", "")
    p.village("Viskla", "")
    p.village("Sõmeru", "")
    p.village("Tammiku", "75119")
    p.village("Nõrava", "75116")
    p.village("Raveliku", "75112")
    p.village("Vilama", "75110")
    p.village("Kata", "75120")
    p.village("Kolu", "75121")
    p.village("Kuivajõe", "75123")
    p.village("Võlle", "75109")
    p.village("Kanavere", "75105")

    p.municipality("Padise", "")
    p.village("Madise", "")
    p.village("Kurkse", "")
    p.village("Harju-Risti", "")
    p.village("Kõmmaste", "76016")
    p.village("Keibu", "76019")
    p.village("Vintse", "76021")
    p.village("Alliklepa", "76018")
    p.village("Määra", "76010")
    p.village("Vihterpalu", "76003")
    p.village("Audevälja", "76005")
    p.village("Altküla", "76012")
    p.village("Vilivalla", "76020")
    p.village("Pae", "76015")
    p.village("Hatu", "76013")
    p.village("Metslõugu", "76009")
    p.village("Langa", "76711")
    p.village("Laane", "")
    p.village("Kasepere", "76007")
    p.village("Pedase", "76014")
    p.village("Änglema", "76022")
    p.village("Karilepa", "76006")
    p.village("Suurküla", "76011")
    p.village("Kobru", "76004")

    p.municipality("Kõue", "")
    p.smallborough("Ardu", "")
    p.smallborough("Habaja", "")
    p.village("Harmi", "75034")
    p.village("Virla", "75021")
    p.village("Paunaste", "75025")
    p.village("Aela", "75004")
    p.village("Katsina", "75005")
    p.village("Rõõsa", "75015")
    p.village("Kadja", "75003")
    p.village("Saarnakõrve", "75023")
    p.village("Kantküla", "75027")
    p.village("Vahetüki", "75020")
    p.village("Uueveski", "75037")
    p.village("Sae", "75016")
    p.village("Kukepala", "75010")
    p.village("Puusepa", "75017")
    p.village("Kõrvenurga", "75008")
    p.village("Kiruvere", "75006")
    p.village("Nutu", "75012")
    p.village("Alansi", "75035")
    p.village("Lutsu", "75030")
    p.village("Kirivalla", "75036")
    p.village("Paunküla", "75011")
    p.village("Riidamäe", "75032")
    p.village("Äksi", "75038")
    p.village("Silmsi", "75024")
    p.village("Ojasoo", "75031")
    p.village("Rava", "75014")
    p.village("Sääsküla", "75033")
    p.village("Lööra", "75028")
    p.village("Leistu", "75026")
    p.village("Marguse", "75029")
    p.village("Triigi", "75019")
    p.village("Nõmmeri", "75013")

    p.municipality("Kuusalu", "")
    p.smallborough("Kolga", "")
    p.smallborough("Kiiu", "")
    p.village("Valkla", "")
    p.village("Viinistu", "")
    p.village("Kaberla", "")
    p.village("Mäepea", "")
    p.village("Sõitme", "")
    p.village("Uuri", "")
    p.village("Mustametsa", "")
    p.village("Kolga-Aabla", "")
    p.village("Salmistu", "")
    p.village("Kiiu-Aabla", "")
    p.village("Vihasoo", "")
    p.village("Kõnnu", "")
    p.village("Allika", "")
    p.village("Leesi", "")
    p.village("Suurpea", "74812")
    p.village("Saunja", "74636")
    p.village("Valgejõe", "74712")
    p.village("Haavakannu", "74628")
    p.village("Nõmmeveski", "74815")
    p.village("Tapurla", "74721")
    p.village("Kemba", "74708")
    p.village("Kodasoo", "74632")
    p.village("Virve", "74814")
    p.village("Hirvli", "74607")
    p.village("Parksi", "74710")
    p.village("Tsitre", "74616")
    p.village("Tõreska", "74617")
    p.village("Koitjärve", "74622")
    p.village("Tammispea", "74715")
    p.village("Põhja", "74635")
    p.village("Muuksi", "74612")
    p.village("Suru", "74615")
    p.village("Kalme", "74714")
    p.village("Juminda", "74716")
    p.village("Pala", "")
    p.village("Kolgaküla", "74808")
    p.village("Tammistu", "74719")
    p.village("Hara", "74810")
    p.village("Pärispea", "74706")
    p.village("Liiapeksi", "74709")
    p.village("Pudisoo", "74626")
    p.village("Murksi", "74713")
    p.village("Joaveski", "74813")
    p.village("Kahala", "74621")
    p.village("Aru", "74606")
    p.village("Turbuneeme", "74707")
    p.village("Kursi", "74611")
    p.village("Pedaspea", "74718")
    p.village("Kolgu", "74618")
    p.village("Kasispea", "74811")
    p.village("Rehatse", "74624")
    p.village("Kosu", "74608")
    p.village("Vanaküla", "74711")
    p.village("Ilmastalu", "74619")
    p.village("Sigula", "74625")
    p.village("Kotka", "74809")
    p.village("Soorinna", "74614")
    p.village("Külmaallika", "74634")
    p.village("Kupu", "74610")

    p.municipality("Kernu", "")
    p.village("Laitse", "")
    p.village("Haiba", "")
    p.village("Ruila", "")
    p.village("Kustja", "")
    p.village("Mõnuste", "76310")
    p.village("Kirikla", "76306")
    p.village("Kabila", "")
    p.village("Metsanurga", "")
    p.village("Hingu", "76312")
    p.village("Kohatu", "76304")
    p.village("Muusika", "76309")

    p.municipality("Aegviidu", "")
    p.municipality("Kaasiku", "")
    p.municipality("Kibuna", "")
    p.municipality("Vahastu", "")
    p.municipality("Vansi", "")
    p.municipality("Vikipalu", "")
    p.municipality("Jägala-Joa", "")
    p.municipality("Kersalu", "")
    p.municipality("Haapse", "")
    p.municipality("Jõesuu", "")
    p.municipality("Pohla", "")
    p.municipality("Andineeme", "")

