# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Viljandi (county)
    p.county("Viljandi", "")
    p.municipality("Suure-Jaani", "")
    p.village("Vastemõisa", "")
    p.village("Ülde", "")
    p.village("Võivaku", "")
    p.village("Reegoldi", "")
    p.village("Jälevere", "")
    p.village("Nuutre", "")
    p.smallborough("Olustvere", "")
    p.village("Lõhavere", "")
    p.village("Sürgavere", "")
    p.village("Päraküla", "")
    p.village("Tääksi", "")
    p.village("Kõidama", "")
    p.village("Kärevere", "70407")
    p.village("Karjasoo", "71408")
    p.village("Metsküla", "71302")
    p.village("Tällevere", "71511")
    p.village("Jaska", "70404")
    p.village("Ivaski", "71305")
    p.village("Kobruvere", "71306")
    p.village("Vihi", "71402")
    p.village("Mudiste", "70405")
    p.village("Kootsi", "71411")
    p.village("Mäeküla", "")
    p.village("Aimla", "70403")
    p.village("Navesti", "70406")
    p.village("Kurnuvere", "70412")
    p.village("Võhmassaare", "70606")
    p.village("Epra", "71405")
    p.village("Arjadi", "71505")
    p.village("Munsi", "71403")
    p.village("Ilbaku", "71307")
    p.village("Lahmuse", "71412")
    p.village("Ängi", "71507")
    p.village("Rääka", "71409")
    p.village("Taevere", "71510")
    p.village("Kildu", "71303")
    p.village("Sandra", "71309")
    p.village("Kibaru", "71506")
    p.village("Kuhjavere", "70414")
    p.village("Kuiavere", "70408")
    p.village("Paelama", "71308")
    p.village("Põhjaka", "71410")
    p.village("Kabila", "71404")
    p.village("Riiassaare", "70415")
    p.village("Kerita", "71406")
    p.village("Võlli", "71512")
    p.village("Lemmakõnnu", "71304")

    p.municipality("Abja", "")
    p.town("Abja-Paluoja", "")
    p.village("Veskimäe", "")
    p.village("Penuja", "")
    p.village("Abja-Vanamõisa", "")
    p.village("Põlde", "")
    p.village("Raamatu", "69308")
    p.village("Sarja", "69407")
    p.village("Atika", "69411")
    p.village("Saate", "69202")
    p.village("Veelikse", "69307")
    p.village("Umbsoo", "69309")
    p.village("Kamara", "69304")
    p.village("Räägu", "69310")
    p.village("Lasari", "69306")
    p.village("Laatre", "69305")
    p.village("Abjaku", "69410")

    p.town("Viljandi", "")
    p.town("Võhma", "")
    p.town("Mõisaküla", "")
    p.municipality("Viiratsi", "")
    p.village("Uusna", "")
    p.village("Vana-Võidu", "")
    p.village("Vardja", "")
    p.village("Tänassilma", "")
    p.village("Mähma", "")
    p.village("Jõeküla", "")
    p.village("Loime", "")
    p.village("Tõnuküla", "")
    p.village("Valma", "")
    p.village("Kibeküla", "69619")
    p.village("Saareküla", "70112")
    p.village("Vanavälja", "70114")
    p.village("Mäeltküla", "70105")
    p.village("Kuudeküla", "70111")
    p.village("Verilaske", "70110")
    p.village("Surva", "70115")
    p.village("Rebaste", "70117")
    p.village("Ridaküla", "70122")
    p.village("Vasara", "70107")
    p.village("Tusti", "70113")
    p.village("Ruudiküla", "70106")

    p.municipality("Halliste", "")
    p.village("Mõõnaste", "")
    p.village("Päidre", "")
    p.village("Kalvre", "")
    p.village("Hõbemäe", "69507")
    p.village("Ülemõisa", "69512")
    p.village("Maru", "69522")
    p.village("Naistevalla", "69519")
    p.smallborough("Õisu", "69502")
    p.village("Raja", "69503")
    p.village("Uue-Kariste", "69504")
    p.village("Vabamatsi", "69405")
    p.village("Rimmu", "69505")
    p.village("Mulgi", "69516")
    p.village("Pornuse", "69508")
    p.village("Kulla", "69509")
    p.village("Ereste", "69511")
    p.village("Saksaküla", "69520")
    p.village("Toosi", "69514")
    p.village("Päigiste", "69408")
    p.village("Kaarli", "69510")
    p.village("Tilla", "69517")
    p.village("Sammaste", "69521")
    p.village("Vana-Kariste", "69506")
    p.village("Niguli", "69515")

    p.municipality("Karksi", "")
    p.town("Karksi-Nuia", "")
    p.village("Kõvaküla", "")
    p.village("Morna", "")
    p.village("Univere", "")
    p.village("Polli", "")
    p.village("Lilli", "")
    p.village("Metsaküla", "69109")
    p.village("Hirmuküla", "69003")
    p.village("Leeli", "69106")
    p.village("Suuga", "71053")
    p.village("Muri", "71054")
    p.village("Sudiste", "69001")
    p.village("Ainja", "69105")
    p.village("Tuhalaane", "71056")
    p.village("Pärsi", "69110")
    p.village("Allaste", "69113")
    p.village("Äriküla", "69115")
    p.village("Pöögle", "69111")
    p.village("Oti", "69114")

    p.municipality("Kolga-Jaani", "")
    p.village("Leie", "")
    p.village("Parika", "70307")
    p.village("Eesnurga", "70306")
    p.village("Kaavere", "70318")
    p.village("Järtsaare", "70302")
    p.village("Oorgu", "70309")
    p.village("Odiste", "70308")
    p.village("Oiu", "70317")
    p.village("Vissuvere", "70311")
    p.village("Taganurga", "70310")
    p.village("Otiküla", "70316")
    p.village("Meleski", "70304")
    p.village("Vaibla", "70314")
    p.village("Lalsi", "70313")
    p.village("Lätkalu", "70315")

    p.municipality("Pärsti", "")
    p.village("Päri", "")
    p.village("Jämejala", "")
    p.smallborough("Ramsi", "")
    p.village("Kiisa", "")
    p.village("Vardi", "")
    p.village("Heimtali", "")
    p.village("Raudna", "")
    p.village("Rihkama", "")
    p.village("Puiatu", "")
    p.village("Mustivere", "")
    p.village("Matapera", "")
    p.village("Sinialliku", "")
    p.village("Pinska", "")
    p.village("Marna", "71108")
    p.village("Vanamõisa", "71119")
    p.village("Tõrreküla", "71111")
    p.village("Kookla", "71120")
    p.village("Savikoti", "71103")
    p.village("Kiini", "71125")
    p.village("Leemeti", "71122")
    p.village("Turva", "71112")
    p.village("Väike-Kõpu", "71124")
    p.village("Alustre", "71057")
    p.village("Laanekuru", "71107")
    p.village("Tohvri", "71114")
    p.village("Kingu", "71121")

    p.municipality("Tarvastu", "")
    p.village("Kärstna", "")
    p.smallborough("Mustla", "")
    p.village("Kivilõppe", "69706")
    p.village("Jakobimõisa", "69705")
    p.village("Porsa", "69710")
    p.village("Riuma", "69736")
    p.village("Pahuvere", "69725")
    p.village("Kalbuse", "69737")
    p.village("Vanausse", "69713")
    p.village("Pikru", "69709")
    p.village("Kuressaare", "69708")
    p.village("Maltsa", "69731")
    p.village("Muksi", "69724")
    p.village("Ülensi", "69720")
    p.village("Vilimeeste", "69718")
    p.village("Koidu", "69707")
    p.village("Raassilla", "69722")
    p.village("Põrga", "69726")
    p.village("Tinnikuru", "69716")
    p.village("Unametsa", "69717")
    p.village("Vooru", "69733")
    p.village("Villa", "69719")
    p.village("Järveküla", "69732")
    p.village("Metsla", "69711")
    p.village("Suislepa", "")
    p.village("Veisjärve", "69729")
    p.village("Väluste", "69704")
    p.village("Tagamõisa", "69727")
    p.village("Marjamäe", "69734")
    p.village("Roosilla", "69730")
    p.village("Mõnnaste", "69735")
    p.village("Ämmuste", "69721")
    p.village("Kannuküla", "69728")
    p.village("Anikatsi", "69723")
    p.village("Sooviku", "69714")

    p.municipality("Saarepeedi", "")
    p.village("Peetrimõisa", "")
    p.village("Võistre", "")
    p.village("Karula", "")
    p.village("Moori", "70211")
    p.village("Tõnissaare", "71069")
    p.village("Auksi", "71064")
    p.village("Välgita", "")
    p.village("Taari", "71072")
    p.village("Aindu", "71063")
    p.village("Kokaviidika", "71071")
    p.village("Tobraselja", "71068")

    p.municipality("Paistu", "")
    p.village("Sultsi", "")
    p.village("Loodi", "")
    p.village("Intsu", "")
    p.village("Holstre", "")
    p.village("Rebase", "69610")
    p.village("Pulleritsu", "69609")
    p.village("Luiga", "69606")
    p.village("Aidu", "69604")
    p.village("Tömbi", "69608")
    p.village("Viisuküla", "69607")
    p.village("Kassi", "71052")
    p.village("Mustapali", "69618")
    p.village("Pirmastu", "69620")
    p.village("Lolu", "69617")
    p.village("Hendrikumõisa", "69612")

    p.municipality("Kõpu", "")
    p.village("Tipu", "")
    p.village("Uia", "71206")
    p.village("Supsi", "71205")
    p.village("Iia", "71210")
    p.village("Vanaveski", "71207")
    p.village("Laane", "71202")
    p.village("Kuninga", "69518")
    p.village("Punaküla", "71204")
    p.village("Seruküla", "71203")

    p.municipality("Kõo", "")
    p.village("Soomevere", "")
    p.village("Paaksima", "70607")
    p.village("Koksvere", "70604")
    p.village("Saviaugu", "70503")
    p.village("Pilistvere", "70502")
    p.village("Maalasti", "70608")
    p.village("Kirivere", "70506")
    p.village("Unakvere", "70508")
    p.village("Arjassaare", "70507")
    p.village("Arussaare", "70605")
    p.village("Paenasti", "70509")
    p.village("Kangrussaare", "70505")
    p.village("Loopre", "70504")
    p.village("Venevere", "70511")

    p.municipality("Soe", "")

