# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Võru (county)
    p.county("Võru", "")
    p.municipality("Vastseliina", "")
    p.village("Pari", "65258")
    p.village("Vana-Vastseliina", "65254")
    p.village("Lindora", "65224")
    p.village("Loosi", "65260")
    p.village("Plessi", "65328")
    p.village("Jeedasküla", "65212")
    p.village("Perametsa", "65234")
    p.village("Indra", "65259")
    p.village("Tsolli", "")
    p.village("Kerepäälse", "65217")
    p.village("Halla", "65204")
    p.village("Holsta", "65208")
    p.village("Raadi", "65237")
    p.village("Voki", "65257")
    p.village("Ortuma", "65231")
    p.village("Vatsa", "65255")
    p.village("Luhte", "65171")
    p.village("Kapera", "65216")
    p.village("Külaoru", "65223")
    p.village("Tellaste", "65247")
    p.village("Kõrve", "65221")
    p.village("Kündja", "65168")
    p.village("Tabina", "65246")
    p.village("Mutsu", "65226")
    p.village("Puutli", "65235")
    p.village("Kaagu", "65214")
    p.village("Kornitsa", "65219")
    p.village("Kirikumäe", "65218")
    p.village("Juraski", "65213")
    p.village("Heinasoo", "65205")
    p.village("Illi", "65210")
    p.village("Vana-Saaluse", "65253")
    p.village("Tallikeste", "65337")
    p.village("Viitka", "65256")
    p.village("Sutte", "65245")
    p.village("Kõo", "65165")
    p.village("Hinniala", "65206")
    p.village("Hinsa", "65207")
    p.village("Käpa", "65222")
    p.village("Saarde", "65239")
    p.village("Mäe-Kõoküla", "65227")

    p.town("Võru", "65620")
    p.smallborough("Väimela", "65566")
    p.smallborough("Parksepa", "65509")
    p.village("Võlsi", "")
    p.village("Roosisaare", "")
    p.village("Võrumõisa", "")
    p.village("Verijärve", "")
    p.village("Puiga", "")
    p.smallborough("Kose", "")
    p.village("Lompka", "65525")
    p.village("Sika", "")
    p.village("Hannuste", "65515")
    p.village("Käätso", "65524")
    p.village("Kusma", "65523")
    p.village("Nooska", "65531")
    p.village("Võrusoo", "65565")
    p.village("Kolepi", "65520")
    p.village("Vagula", "65553")
    p.village("Tagaküla", "65514")
    p.village("Kasaritsa", "65519")
    p.village("Väiso", "65503")
    p.village("Räpo", "65535")
    p.village("Umbsaare", "65538")
    p.village("Loosu", "65548")
    p.village("Juba", "65518")
    p.village("Mõisamäe", "65529")
    p.village("Palometsa", "65532")
    p.village("Vana-Nursi", "65540")
    p.village("Mõksi", "65530")
    p.village("Raiste", "65513")
    p.village("Tootsi", "65537")
    p.village("Meeliku", "65527")
    p.village("Kärnamäe", "65504")
    p.village("Lapi", "65505")
    p.village("Koloreino", "65521")

    p.town("Antsla", "")
    p.smallborough("Vana-Antsla", "")
    p.village("Tsooru", "")
    p.village("Säre", "")
    p.smallborough("Kobela", "")
    p.village("Kraavi", "66409")
    p.village("Kaika", "66421")
    p.village("Savilöövi", "66307")
    p.village("Anne", "66423")
    p.village("Antsu", "66424")
    p.village("Soome", "66415")
    p.village("Luhametsa", "66304")
    p.village("Madise", "66411")
    p.village("Oe", "66422")
    p.village("Kikkaoja", "66302")
    p.village("Taberlaane", "66417")
    p.village("Lusti", "66410")
    p.village("Litsmetsa", "66303")
    p.village("Mähkli", "66412")
    p.village("Jõepera", "66425")
    p.village("Ähijärve", "66420")
    p.village("Viirapalu", "66308")
    p.village("Haabsaare", "66405")
    p.village("Roosiku", "66306")
    p.village("Piisi", "66305")
    p.village("Kollino", "66408")
    p.village("Rimmi", "66414")

    p.municipality("Varstu", "")
    p.village("Punsa", "66107")
    p.village("Krabi", "66102")
    p.village("Vana-Roosa", "66109")
    p.village("Kangsti", "66103")
    p.village("Metstaga", "66106")
    p.village("Viru", "66309")
    p.village("Mutemetsa", "66114")
    p.village("Paganamaa", "66115")
    p.village("Hintsiko", "66110")
    p.village("Kõrgepalu", "66104")
    p.village("Laurimäe", "66111")
    p.village("Tagakolga", "66118")
    p.village("Harjuküla", "66120")
    p.village("Lüütsepa", "66113")
    p.village("Liguri", "66112")
    p.village("Soolätte", "66117")
    p.village("Raudsepa", "")
    p.village("Pähni", "66116")

    p.municipality("Sõmerpalu", "")
    p.village("Haava", "")
    p.village("Mustja", "66614")
    p.village("Leiso", "66634")
    p.village("Rummi", "66640")
    p.village("Udsali", "")
    p.village("Heeska", "66625")
    p.village("Kurenurme", "66631")
    p.village("Hargi", "66624")
    p.village("Mäekülä", "66615")
    p.village("Järvere", "66629")
    p.village("Linnamäe", "66635")
    p.village("Mustassaare", "66637")
    p.village("Horma", "66626")
    p.village("Pritsi", "66638")
    p.village("Haidaku", "66623")
    p.village("Osula", "66602")
    p.village("Majala", "66636")
    p.village("Hutita", "66627")
    p.village("Kärgula", "66632")
    p.village("Liiva", "66514")
    p.village("Kahro", "66617")
    p.village("Rauskapalu", "66639")
    p.village("Keema", "66511")
    p.village("Haamaste", "66616")
    p.village("Alakülä", "66620")
    p.village("Varese", "66642")
    p.village("Lakovitsa", "66633")
    p.village("Alapõdra", "66621")
    p.village("Punakülä", "66619")
    p.village("Lilli-Anne", "66613")
    p.village("Hänike", "66628")

    p.municipality("Rõuge", "")
    p.village("Hallimäe", "")
    p.village("Horsa", "")
    p.village("Kahru", "")
    p.village("Tüütsi", "66703")
    p.village("Rebäsemõisa", "66276")
    p.village("Pulli", "")
    p.village("Märdi", "66260")
    p.village("Laossaarõ", "66246")
    p.village("Savioru", "66285")
    p.village("Suurõ-Ruuga", "66292")
    p.village("Nilbõ", "66262")
    p.village("Vanamõisa", "66707")
    p.village("Tallima", "66293")
    p.village("Simmuli", "66288")
    p.village("Hapsu", "66214")
    p.village("Lauri", "66247")
    p.village("Sikalaanõ", "66287")
    p.village("Haki", "66209")
    p.village("Raudsepä", "66274")
    p.village("Soemõisa", "66290")
    p.village("Tiidu", "66296")
    p.village("Muhkamõtsa", "66255")
    p.village("Mõõlu", "66259")
    p.village("Kokõjüri", "66237")
    p.village("Kuuda", "66243")
    p.village("Kiidi", "66234")
    p.village("Möldri", "")
    p.village("Püssä", "66272")
    p.village("Kogrõ", "66235")
    p.village("Mikita", "")
    p.village("Vadsa", "66706")
    p.village("Viitina", "66711")
    p.village("Järvekülä", "66223")
    p.village("Hinu", "66217")
    p.village("Jugu", "66222")
    p.village("Kaugu", "66231")
    p.village("Soomõoru", "66291")
    p.village("Sandisuu", "66284")
    p.village("Matsi", "")
    p.village("Viliksaarõ", "66708")
    p.village("Nogu", "66263")
    p.village("Järvepalu", "66224")
    p.village("Rasva", "66273")
    p.village("Ahitsa", "66206")
    p.village("Väiku-Ruuga", "66709")
    p.village("Sadramõtsa", "66282")
    p.village("Handimiku", "66213")
    p.village("Augli", "66207")
    p.village("Aabra", "66205")
    p.village("Saarlasõ", "66281")
    p.village("Kurgjärve", "66241")
    p.village("Tilgu", "66297")
    p.village("Hansi", "65516")
    p.village("Toodsi", "")
    p.village("Rebäse", "")
    p.village("Kurvitsa", "66242")
    p.village("Hurda", "")
    p.village("Murdõmäe", "66257")
    p.village("Heedu", "66215")
    p.village("Muna", "66256")
    p.village("Tialasõ", "66295")
    p.village("Petrakuudi", "66267")
    p.village("Roobi", "66279")
    p.village("Kähri", "66244")
    p.village("Tsirgupalu", "66701")
    p.village("Nursi", "66712")
    p.village("Põru", "66271")
    p.village("Paaburissa", "66265")
    p.village("Utessuu", "66705")
    p.village("Karaski", "66229")
    p.village("Pugõstu", "66268")
    p.village("Kaluka", "66228")
    p.village("Sänna", "66710")
    p.village("Kolga", "66239")
    p.village("Tsutsu", "66702")
    p.village("Lutika", "66250")
    p.village("Paeboja", "66266")
    p.village("Põdra", "66270")
    p.village("Ruuksu", "66280")
    p.village("Kokõ", "66236")
    p.village("Kellämäe", "66233")
    p.village("Kavõldi", "66232")
    p.village("Saki", "66283")
    p.village("Kokõmäe", "66238")
    p.village("Heibri", "66216")
    p.village("Taudsa", "66294")
    p.village("Liivakupalu", "66248")
    p.village("Haabsilla", "66208")
    p.village("Kadõni", "66225")
    p.village("Ortumäe", "66264")
    p.village("Pärlijõe", "66211")
    p.village("Soekõrdsi", "66289")
    p.village("Tindi", "66298")
    p.village("Hotõmäe", "66218")
    p.village("Karba", "66230")
    p.village("Muduri", "66254")
    p.village("Kängsepä", "66245")
    p.village("Jaanipeebu", "66221")
    p.village("Lükkä", "66251")
    p.village("Kuklasõ", "66240")
    p.village("Härämäe", "66220")
    p.village("Riitsilla", "66277")
    p.village("Ristemäe", "66278")

    p.municipality("Mõniste", "")
    p.village("Hürova", "")
    p.village("Karisöödi", "66005")
    p.village("Koemetsa", "66006")
    p.village("Peebu", "66007")
    p.village("Parmupalu", "66015")
    p.village("Kallaste", "")
    p.village("Singa", "66010")
    p.village("Saru", "66009")
    p.village("Sakurgi", "66008")
    p.village("Tiitsa", "66011")
    p.village("Tursa", "66012")
    p.village("Tundu", "66016")
    p.village("Kuutsi", "66018")
    p.village("Hüti", "66014")
    p.village("Villike", "66017")
    p.village("Vastse-Roosa", "66013")

    p.municipality("Haanja", "")
    p.village("Pausakunnu", "65131")
    p.village("Andsumäe", "")
    p.village("Mustahamba", "")
    p.village("Mäe-Suhka", "65128")
    p.village("Mäe-Tilga", "65129")
    p.village("Tsiamäe", "65144")
    p.village("Soodi", "65142")
    p.village("Trolla", "65143")
    p.village("Purka", "65137")
    p.village("Posti", "65183")
    p.village("Kirbu", "65118")
    p.village("Vaarkali", "")
    p.village("Kääraku", "65120")
    p.village("Tsiiruli", "65196")
    p.village("Haavistu", "65105")
    p.village("Tsilgutaja", "65198")
    p.village("Lillimõisa", "65169")
    p.village("Saluora", "65190")
    p.village("Märdimiku", "65177")
    p.village("Rusa", "65189")
    p.village("Vastsekivi", "65191")
    p.village("Käänu", "65167")
    p.village("Holdi", "")
    p.village("Vaalimäe", "65148")
    p.village("Tõnkova", "65166")
    p.village("Mäe-Palo", "65176")
    p.village("Pressi", "65136")
    p.village("Kergatsi", "65117")
    p.village("Kuiandi", "65162")
    p.village("Ihatsi", "65109")
    p.village("Kaldemäe", "65114")
    p.village("Raagi", "65188")
    p.village("Horoski", "65107")
    p.village("Pillardi", "65182")
    p.village("Külma", "65121")
    p.village("Kaaratautsa", "65113")
    p.village("Sarise", "65192")
    p.village("Saika", "")
    p.village("Hulaku", "65156")
    p.village("Palanumäe", "65130")
    p.village("Preeksa", "65184")
    p.village("Naapka", "65178")
    p.village("Kriguli", "65161")
    p.village("Ala-Suhka", "65103")
    p.village("Sormuli", "65194")
    p.village("Vihkla", "65193")
    p.village("Kuklase", "65163")
    p.village("Palli", "65179")
    p.village("Ruusmäe", "65102")
    p.village("Loogamäe", "65170")
    p.village("Meelaku", "65125")
    p.village("Murati", "65174")
    p.village("Uue-Saaluse", "65147")
    p.village("Lüütsepä", "65172")
    p.village("Ala-Palo", "65152")
    p.village("Mallika", "65124")
    p.village("Mahtja", "65123")
    p.village("Kaloga", "65116")
    p.village("Vungi", "65181")
    p.village("Ala-Tilga", "65104")
    p.village("Resto", "65138")
    p.village("Leoski", "65122")
    p.village("Palujüri", "65180")
    p.village("Tummelka", "65146")
    p.village("Vänni", "65151")
    p.village("Hanija", "65155")
    p.village("Plaksi", "65135")
    p.village("Kilomani", "65159")
    p.village("Piipsemäe", "65133")
    p.village("Luutsniku", "65110")
    p.village("Puspuri", "65186")
    p.village("Hämkoti", "65108")
    p.village("Simula", "65141")
    p.village("Vorstimäe", "65197")
    p.village("Miilimäe", "65126")
    p.village("Kuura", "65164")
    p.village("Kõomäe", "65119")
    p.village("Söödi", "65195")
    p.village("Plaani", "65134")
    p.village("Vakari", "65149")
    p.village("Peedo", "65132")
    p.village("Tuuka", "65199")
    p.village("Pundi", "65185")
    p.village("Kotka", "65160")

    p.municipality("Urvaste", "")
    p.village("Kuldre", "")
    p.village("Lümatu", "66515")
    p.village("Uhtjärve", "66508")
    p.village("Visela", "66510")
    p.village("Kirikuküla", "66512")
    p.village("Pihleni", "66506")
    p.village("Vaabina", "66519")
    p.village("Uue-Antsla", "66509")
    p.village("Koigu", "66513")
    p.village("Kassi", "66504")
    p.village("Kõlbi", "66505")
    p.village("Toku", "66507")
    p.village("Ruhingu", "66516")

    p.municipality("Lasva", "")
    p.village("Nõnova", "65230")
    p.village("Lauga", "65506")
    p.village("Listaku", "")
    p.village("Kõrgessaare", "65404")
    p.village("Kaku", "")
    p.village("Kääpa", "65545")
    p.village("Puusepa", "65551")
    p.village("Mõrgi", "65549")
    p.village("Peraküla", "65510")
    p.village("Noodasküla", "65229")
    p.village("Kannu", "65544")
    p.village("Saaremaa", "65240")
    p.village("Kühmamäe", "65405")
    p.village("Madala", "65406")
    p.village("Tohkri", "65249")
    p.village("Oleski", "65507")
    p.village("Mäessaare", "65407")
    p.village("Tammsaare", "65413")
    p.village("Rusima", "65412")
    p.village("Lehemetsa", "65546")
    p.village("Sooküla", "65244")
    p.village("Voki-Tamme", "65415")
    p.village("Tüütsmäe", "65251")
    p.village("Pindi", "65410")
    p.village("Tiri", "65414")
    p.village("Villa", "")
    p.village("Pässä", "65411")
    p.village("Hellekunnu", "65402")
    p.village("Otsa", "65408")
    p.village("Pikasilla", "65511")
    p.village("Pikakannu", "65409")
    p.village("Pille", "65512")
    p.village("Tsolgo", "65552")
    p.village("Husari", "65403")
    p.village("Paidra", "65508")

    p.municipality("Misso", "")
    p.village("Häärmäni", "65209")
    p.village("Põnni", "65042")
    p.village("Mokra", "65020")
    p.village("Kärinä", "65041")
    p.village("Sapi", "65242")
    p.village("Pupli", "65026")
    p.village("Tserebi", "65039")
    p.village("Tiastõ", "65036")
    p.village("Tiilige", "65037")
    p.village("Ritsiko", "65029")
    p.village("Kriiva", "65013")
    p.village("Põrstõ", "65027")
    p.village("Suurõsuu", "65035")
    p.village("Lütä", "65018")
    p.village("Tika", "65248")
    p.village("Määsi", "65045")
    p.village("Kaubi", "65006")
    p.village("Parmu", "65023")
    p.village("Hürsi", "65158")
    p.village("Savimäe", "65033")
    p.village("Savioja", "")
    p.village("Korgõssaarõ", "65010")
    p.village("Mauri", "65225")
    p.village("Horosuu", "65005")
    p.village("Pruntova", "65024")
    p.village("Tsiistre", "65002")
    p.village("Laisi", "65016")
    p.village("Kurõ", "65014")
    p.village("Hino", "65004")
    p.village("Pältre", "65236")
    p.village("Koorla", "65009")
    p.village("Muraski", "65021")
    p.village("Siksälä", "65034")
    p.village("Napi", "65022")
    p.village("Kossa", "65012")
    p.village("Kiviora", "65008")
    p.village("Väiko-Tiilige", "65040")
    p.village("Käbli", "65015")
    p.village("Saagri", "")
    p.village("Möldre", "65228")
    p.village("Kundsa", "65220")
    p.village("Hindsa", "65003")
    p.village("Kimalasõ", "65007")
    p.village("Rammuka", "65028")
    p.village("Saagrimäe", "65031")
    p.village("Sakudi", "65032")
    p.village("Pedejä", "65233")
    p.village("Leimani", "65017")
    p.village("Missokülä", "65019")
    p.village("Sandi", "65043")

    p.municipality("Meremäe", "")
    p.village("Obinitsa", "")
    p.village("Kõõru", "65371")
    p.village("Vinski", "65352")
    p.village("Vaaksaarõ", "65350")
    p.village("Ruutsi", "65333")
    p.village("Teterüvä", "65339")
    p.village("Tuulova", "65347")
    p.village("Martsina", "65375")
    p.village("Võmmorski", "65391")
    p.village("Viro", "65353")
    p.village("Antkruva", "65357")
    p.village("Lutja", "65316")
    p.village("Ostrova", "65322")
    p.village("Raotu", "65332")
    p.village("Tessova", "65385")
    p.village("Härmä", "65361")
    p.village("Veretinä", "65390")
    p.village("Lindsi", "65373")
    p.village("Karamsina", "65365")
    p.village("Lepä", "65315")
    p.village("Paklova", "65323")
    p.village("Kiiova", "65366")
    p.village("Miku", "65378")
    p.village("Jaanimäe", "")
    p.village("Väiko-Härmä", "65354")
    p.village("Treiali", "65343")
    p.village("Triginä", "65344")
    p.village("Kuksina", "65314")
    p.village("Pelsi", "65327")
    p.village("Kasakova", "65308")
    p.village("Tsumba", "65386")
    p.village("Tedre", "65384")
    p.village("Marinova", "65317")
    p.village("Rokina", "65381")
    p.village("Kiislova", "65311")
    p.village("Kuigõ", "65313")
    p.village("Tsergondõ", "65345")
    p.village("Tääglova", "65388")
    p.village("Korski", "65369")
    p.village("Palandõ", "65324")
    p.village("Juusa", "65364")
    p.village("Miikse", "65319")
    p.village("Serga", "65334")
    p.village("Tsirgu", "65346")
    p.village("Navikõ", "65379")
    p.village("Küllätüvä", "65372")
    p.village("Ala-Tsumba", "65356")
    p.village("Ermakova", "65358")
    p.village("Maaslova", "65374")
    p.village("Kusnetsova", "65370")
    p.village("Kiksova", "65367")
    p.village("Ulaskova", "65348")
    p.village("Sirgova", "65335")
    p.village("Sulbi", "")
    p.village("Paloveere", "")
    p.village("Tiirhanna", "65340")
    p.village("Tuplova", "65387")
    p.village("Tobrova", "65342")
    p.village("Väiko-Serga", "65355")
    p.village("Talka", "65383")
    p.village("Jõksi", "65305")
    p.village("Hilläkeste", "65303")
    p.village("Tiklasõ", "65341")
    p.village("Masluva", "65376")
    p.village("Pliia", "65329")
    p.village("Kalatsova", "65306")
    p.village("Klistina", "65368")
    p.village("Vasla", "65389")
    p.village("Helbi", "65359")
    p.village("Hilana", "65360")
    p.village("Melso", "65377")
    p.village("Kangavitsa", "65307")
    p.village("Keerba", "65310")
    p.village("Merekülä", "65318")
    p.village("Puista", "65331")
    p.village("Kitsõ", "65312")
    p.village("Olehkova", "65321")
    p.village("Palo", "65325")
    p.village("Ignasõ", "65362")
    p.village("Poksa", "65330")
    p.village("Seretsüvä", "65382")
    p.village("Tepia", "65338")
    p.village("Kastamara", "65309")
    p.village("Polovina", "65380")
    p.village("Uusvada", "65349")

    p.municipality("Kirumpää", "")
    p.municipality("Navi", "")
    p.municipality("Meegomäe", "")
    
