# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Rapla (county)
    p.county("Rapla", "")
    p.municipality("Kehtna", "")
    p.smallborough("Lelle", "")
    p.smallborough("Eidapere", "")
    p.smallborough("Kaerepere", "")
    p.village("Saksa", "")
    p.village("Ohekatku", "")
    p.village("Rõue", "")
    p.smallborough("Keava", "")
    p.village("Käbiküla", "")
    p.village("Metsaääre", "")
    p.village("Kehtna-Nurme", "79051")
    p.village("Laeste", "79064")
    p.village("Koogimäe", "79052")
    p.village("Palasi", "79018")
    p.village("Kärpla", "79063")
    p.village("Kastna", "79016")
    p.village("Vastja", "79071")
    p.village("Lau", "79008")
    p.village("Linnaaluste", "79050")
    p.village("Reonda", "79015")
    p.village("Kõrbja", "79023")
    p.village("Selja", "79110")
    p.village("Ellamaa", "79011")
    p.village("Sooaluste", "79070")
    p.village("Ahekõnnu", "79111")
    p.village("Kalbu", "79061")
    p.village("Mukri", "79013")
    p.village("Saarepõllu", "79014")
    p.village("Lokuta", "")
    p.village("Põrsaku", "79524")
    p.village("Hertu", "79521")
    p.village("Pae", "79009")
    p.village("Nadalama", "79068")
    p.village("Lellapere-Nurme", "79066")
    p.village("Lalli", "79017")
    p.village("Nõlva", "79112")
    p.village("Hiie", "79060")
    p.village("Kenni", "79012")
    p.village("Haakla", "79021")
    p.village("Paluküla", "79019")
    p.village("Saunaküla", "79526")
    p.village("Koogiste", "79022")
    p.village("Lellapere", "79065")
    p.village("Valtu-Nurme", "79527")
    p.village("Kumma", "79523")
    p.village("Ingliste", "79004")
    p.village("Põllu", "79020")

    p.town("Rapla", "")
    p.village("Uusküla", "")
    p.smallborough("Hagudi", "")
    p.smallborough("Alu", "")
    p.village("Sulupere", "")
    p.village("Mahlamäe", "")
    p.village("Tuti", "")
    p.smallborough("Kuusiku", "")
    p.village("Kalevi", "")
    p.village("Kuku", "")
    p.village("Purila", "")
    p.village("Valtu", "")
    p.village("Kodila", "")
    p.village("Sikeldi", "")
    p.village("Ülejõe", "")
    p.village("Oola", "79643")
    p.village("Kõrgu", "79615")
    p.village("Alu-Metsküla", "79605")
    p.village("Seli", "79604")
    p.village("Tõrma", "79622")
    p.village("Seli-Nurme", "79634")
    p.village("Röa", "79614")
    p.village("Aranküla", "79640")
    p.village("Oela", "79617")
    p.village("Ohulepa", "79618")
    p.village("Kodila-Metsküla", "79613")
    p.village("Äherdi", "79644")
    p.village("Juula", "79540")
    p.village("Mõisaaseme", "79632")
    p.village("Tapupere", "79621")
    p.village("Ridaküla", "79528")
    p.village("Palamulla", "79619")
    p.village("Väljataguse", "79543")
    p.village("Lipstu", "79519")
    p.village("Kelba", "79611")
    p.village("Koigi", "79630")
    p.village("Kuusiku-Nõmme", "79518")
    p.village("Mällu", "79616")
    p.village("Nõmme", "79642")
    p.village("Raka", "79620")
    p.village("Iira", "79517")

    p.municipality("Märjamaa", "")
    p.village("Sõtke", "")
    p.village("Maidla", "")
    p.village("Sipa", "")
    p.village("Moka", "78236")
    p.village("Kasti", "78221")
    p.village("Vana-Nurtu", "78258")
    p.village("Kangru", "78220")
    p.village("Sõmeru", "78255")
    p.village("Purga", "78249")
    p.village("Velise-Nõlva", "78260")
    p.village("Laukna", "")
    p.village("Napanurga", "78240")
    p.village("Inda", "78216")
    p.village("Pajaka", "78248")
    p.village("Risu-Suurküla", "78252")
    p.village("Veski", "78261")
    p.village("Urevere", "78120")
    p.village("Mõraste", "78116")
    p.village("Loodna", "78113")
    p.village("Kiilaspere", "78223")
    p.village("Paisumaa", "78247")
    p.village("Aravere", "78213")
    p.village("Valgu", "78204")
    p.village("Vanamõisa", "")
    p.village("Konuvere", "78227")
    p.village("Altküla", "78212")
    p.village("Nõmmeotsa", "78242")
    p.village("Rassiotsa", "78251")
    p.village("Varbola", "78203")
    p.village("Nurme", "78241")
    p.village("Ohukotsu", "78244")
    p.village("Mäliste", "78238")
    p.village("Kohtru", "78226")
    p.village("Russalu", "78317")
    p.village("Leevre", "78112")
    p.village("Keskküla", "78222")
    p.village("Kaguvere", "78219")
    p.village("Alaküla", "78211")
    p.village("Metsküla", "")
    p.village("Velise", "78201")
    p.village("Orgita", "78313")
    p.village("Naistevalla", "78239")
    p.village("Paaduotsa", "78246")
    p.village("Nurtu-Nõlva", "78207")
    p.village("Velisemõisa", "78259")
    p.village("Kilgi", "78224")
    p.village("Paeküla", "78206")
    p.village("Sulu", "78253")
    p.village("Vaimõisa", "78205")
    p.village("Kunsu", "78228")
    p.village("Kirna", "78225")
    p.village("Aruküla", "78214")
    p.village("Vilta", "78121")
    p.village("Võeva", "78262")
    p.village("Lestima", "78232")
    p.village("Käriselja", "78231")
    p.village("Päädeva", "78314")
    p.village("Ojaäärse", "78245")
    p.village("Teenuse", "78103")
    p.village("Nääri", "78243")
    p.village("Põlli", "78250")
    p.village("Sooniste", "78118")
    p.village("Kohatu", "78111")
    p.village("Jõeääre", "78218")
    p.village("Haimre", "78202")
    p.village("Luiste", "78114")
    p.village("Männiku", "78117")
    p.village("Suurküla", "78254")
    p.village("Soosalu", "78119")
    p.village("Rangu", "78315")
    p.village("Ringuta", "78316")
    p.village("Koluta", "78311")
    p.village("Hiietse", "78215")
    p.village("Kõrtsuotsa", "78229")
    p.village("Jaaniveski", "78217")
    p.village("Tolli", "78256")
    p.village("Mõisamaa", "78237")

    p.municipality("Järvakandi", "")
    p.municipality("Juuru", "")
    p.smallborough("Juuru", "")
    p.village("Järlepa", "")
    p.village("Pirgu", "")
    p.village("Orguse", "")
    p.village("Hõreda", "79010")
    p.village("Härgla", "79404")
    p.village("Atla", "79403")
    p.village("Mahtra", "79407")
    p.village("Vankse", "79406")
    p.village("Helda", "79417")
    p.village("Kalda", "79418")
    p.village("Sadala", "79419")
    p.village("Jaluse", "79410")
    p.village("Lõiuse", "79405")

    p.municipality("Kaiu", "")
    p.village("Kuimetsa", "")
    p.village("Oblu", "79312")
    p.village("Karitsa", "79320")
    p.village("Kasvandu", "79321")
    p.village("Tolla", "79322")
    p.village("Põlliku", "79325")
    p.village("Vahastu", "79303")
    p.village("Tamsi", "79313")
    p.village("Vaopere", "79314")
    p.village("Suurekivi", "79333")
    p.village("Toomja", "79323")
    p.village("Vana-Kaiu", "79324")

    p.municipality("Käru", "")
    p.village("Sonni", "")
    p.village("Lauri", "79215")
    p.village("Kõdu", "79212")
    p.village("Kädva", "79213")
    p.village("Lungu", "79216")
    p.village("Kändliku", "79214")
    p.village("Kullimaa", "79211")
    p.village("Jõeküla", "79218")

    p.municipality("Kohila", "")
    p.smallborough("Prillimäe", "")
    p.village("Lohu", "")
    p.village("Urge", "")
    p.smallborough("Hageri", "")
    p.village("Salutaguse", "")
    p.village("Vilivere", "")
    p.village("Sutlema", "")
    p.smallborough("Aespa", "")
    p.village("Masti", "")
    p.village("Pukamäe", "")
    p.village("Angerja", "79741")
    p.village("Lümandu", "")
    p.village("Pihali", "79703")
    p.village("Adila", "79704")
    p.village("Loone", "79831")
    p.village("Põikma", "79709")
    p.village("Rootsi", "79815")
    p.village("Kadaka", "79811")
    p.village("Rabivere", "79610")
    p.village("Aandu", "79810")
    p.village("Mälivere", "79814")
    p.village("Pahkla", "79742")
    p.village("Vana-Aespa", "79748")

    p.municipality("Vigala", "")
    p.village("Vana-Vigala", "78003")
    p.village("Kivi-Vigala", "78001")
    p.village("Kojastu", "78016")
    p.village("Palase", "78025")
    p.village("Tiduvere", "78031")
    p.village("Paljasmaa", "78026")
    p.village("Rääski", "78029")
    p.village("Naravere", "78022")
    p.village("Oese", "78023")
    p.village("Araste", "78011")
    p.village("Kurevere", "78018")
    p.village("Manni", "78021")
    p.village("Vaguja", "78032")
    p.village("Tõnumaa", "78004")
    p.village("Ojapere", "78024")
    p.village("Kausi", "78014")
    p.village("Vängla", "78034")
    p.village("Kesu", "78015")
    p.village("Pallika", "78027")
    p.village("Jädivere", "78013")
    p.village("Sääla", "78030")
    p.village("Läti", "78020")
    p.village("Leibre", "78019")
    p.village("Konnapere", "78017")
    p.village("Päärdu", "78028")
    p.village("Avaste", "78012")

    p.municipality("Raikküla", "")
    p.village("Tamme", "")
    p.village("Loe", "")
    p.village("Nõmmküla", "78408")
    p.village("Jalase", "78415")
    p.village("Purku", "78401")
    p.village("Pühatu", "78421")
    p.village("Keo", "78404")
    p.village("Vahakõnnu", "78411")
    p.village("Põlma", "78410")
    p.village("Lipa", "78405")
    p.village("Lipametsa", "78406")
    p.village("Raela", "78409")
    p.village("Kõrvetaguse", "78417")
    p.village("Riidaku", "78422")
    p.village("Koikse", "78416")
    p.village("Valli", "78413")
    p.village("Nõmmemetsa", "78420")
    p.village("Kaigepere", "78412")
    p.village("Ummaru", "78423")
    p.village("Lõpemetsa", "78419")


