# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Lääne-Viru (county)
    p.county("Lääne-Viru", "")
    p.municipality("Tapa", "")
    p.smallborough("Lehtse", "")
    p.village("Kuru", "")
    p.village("Jäneda", "")
    p.village("Imastu", "45001")
    p.village("Nõmmküla", "")
    p.village("Karkuse", "")
    p.village("Näo", "45007")
    p.village("Linnape", "73606")
    p.village("Läpi", "73607")
    p.village("Läste", "73608")
    p.village("Vahakulmu", "45011")
    p.village("Raudla", "73612")
    p.village("Rabasaare", "73611")
    p.village("Kõrveküla", "")
    p.village("Räsna", "73614")
    p.village("Lokuta", "45004")
    p.village("Patika", "73609")
    p.village("Tõõrakõrve", "73615")
    p.village("Pruuna", "73610")
    p.village("Jootme", "73603")
    p.village("Saiakopli", "45009")
    p.village("Piilu", "45008")
    p.village("Saksi", "45010")
    p.village("Loksu", "45003")
    p.village("Moe", "45005")

    p.municipality("Rakvere", "")
    p.smallborough("Lepna", "")
    p.village("Päide", "")
    p.village("Tõrremäe", "")
    p.village("Veltsi", "")
    p.village("Lasila", "")
    p.village("Taaravainu", "")
    p.village("Kõrgemäe", "")
    p.village("Arkna", "")
    p.village("Tõrma", "44406")
    p.village("Eesküla", "44405")
    p.village("Paatna", "44411")
    p.village("Mädapea", "44409")
    p.village("Karunga", "44404")
    p.village("Levala", "")
    p.village("Kullaaru", "44410")
    p.village("Tobia", "44416")
    p.village("Kloodi", "44413")
    p.village("Järni", "44407")
    p.village("Karivärava", "44412")
    p.village("Karitsa", "44403")

    p.municipality("Vinni", "")
    p.smallborough("Tudu", "")
    p.village("Piira", "")
    p.village("Mõdriku", "")
    p.smallborough("Roela", "")
    p.village("Lähtse", "")
    p.village("Vetiku", "")
    p.village("Kakumäe", "")
    p.village("Küti", "")
    p.smallborough("Pajusti", "")
    p.village("Kadila", "")
    p.smallborough("Viru-Jaagupi", "")
    p.village("Veadla", "")
    p.village("Allika", "46612")
    p.village("Obja", "46629")
    p.village("Anguse", "46615")
    p.village("Kannastiku", "46622")
    p.village("Suigu", "46637")
    p.village("Lepiku", "46627")
    p.village("Koeravere", "46613")
    p.village("Rünga", "46634")
    p.village("Rasivere", "46632")
    p.village("Aravuse", "46616")
    p.village("Kaukvere", "46623")
    p.village("Soonuka", "46636")
    p.village("Palasi", "46630")
    p.village("Nurmetu", "46628")
    p.village("Võhu", "46620")
    p.village("Mäetaguse", "46639")
    p.village("Ristiküla", "46633")
    p.village("Voore", "46642")
    p.village("Puka", "46631")
    p.village("Kulina", "46625")
    p.village("Aruküla", "46617")
    p.village("Alavere", "46611")
    p.village("Inju", "46619")
    p.village("Vana-Vinni", "46640")
    p.village("Saara", "46635")
    p.village("Kehala", "46624")
    p.village("Aruvälja", "46618")

    p.town("Tamsalu", "")
    p.smallborough("Sääse", "")
    p.village("Vajangu", "")
    p.village("Porkuni", "")
    p.village("Assamalla", "")
    p.village("Sauvälja", "46023")
    p.village("Järsi", "46007")
    p.village("Savalduma", "46024")
    p.village("Järvajõe", "46008")
    p.village("Araski", "46005")
    p.village("Uudeküla", "46026")
    p.village("Koplitaguse", "46013")
    p.village("Naistevälja", "46020")
    p.village("Lemmküla", "46017")
    p.village("Vadiküla", "46027")
    p.village("Kerguta", "46011")
    p.village("Vistla", "46028")
    p.village("Kuie", "46014")
    p.village("Kaeva", "46010")
    p.village("Loksa", "46018")
    p.village("Alupere", "46004")
    p.village("Võhmetu", "46029")
    p.village("Kursi", "46016")
    p.village("Võhmuta", "46030")
    p.village("Koiduküla", "46012")
    p.village("Kullenga", "46015")
    p.village("Metskaevu", "46019")
    p.village("Põdrangu", "46022")
    p.village("Piisupi", "46021")
    p.village("Türje", "46025")

    p.municipality("Rakke", "")
    p.village("Suure-Rakke", "")
    p.village("Mõisamaa", "")
    p.village("Edru", "46304")
    p.village("Mäiste", "46320")
    p.village("Kõpsta", "46314")
    p.village("Padaküla", "46323")
    p.village("Tammiku", "")
    p.village("Ao", "46303")
    p.village("Kadiküla", "46308")
    p.village("Väike-Rakke", "46331")
    p.village("Väike-Tammiku", "46332")
    p.village("Emumäe", "46305")
    p.village("Sootaguse", "")
    p.village("Piibe", "46324")
    p.village("Liigvalla", "46318")
    p.village("Olju", "46322")
    p.village("Kellamäe", "46310")
    p.village("Kamariku", "46309")
    p.village("Koluvere", "46313")
    p.village("Kitsemetsa", "46311")
    p.village("Kaavere", "46307")
    p.village("Lahu", "46315")
    p.village("Salla", "46302")
    p.village("Villakvere", "46330")
    p.village("Koila", "")
    p.village("Räitsvere", "46325")
    p.village("Lasinurme", "46317")
    p.village("Lammasküla", "46316")

    p.municipality("Väike-Maarja", "")
    p.smallborough("Simuna", "")
    p.smallborough("Kiltsi", "")
    p.village("Triigi", "")
    p.village("Vao", "")
    p.village("Ebavere", "")
    p.village("Nadalama", "46221")
    p.village("Raigu", "46227")
    p.village("Aburi", "46206")
    p.village("Eipri", "46210")
    p.village("Pikevere", "46204")
    p.village("Käru", "46217")
    p.village("Orguse", "46223")
    p.village("Imukvere", "46212")
    p.village("Koonu", "46213")
    p.village("Pudivere", "46225")
    p.village("Avanduse", "46207")
    p.village("Pandivere", "46224")
    p.village("Rastla", "46228")
    p.village("Varangu", "")
    p.village("Uuemõisa", "46229")
    p.village("Kännuküla", "46215")
    p.village("Raeküla", "46226")
    p.village("Vorsti", "46232")
    p.village("Äntu", "46234")
    p.village("Ärina", "46235")
    p.village("Määri", "46219")
    p.village("Nõmme", "46222")
    p.village("Kurtna", "46214")
    p.village("Aavere", "")
    p.village("Liivaküla", "46218")
    p.village("Võivere", "46233")
    p.village("Avispea", "46208")
    p.village("Hirla", "46211")
    p.village("Kärsa", "46216")
    p.village("Müüriku", "46220")

    p.municipality("Sõmeru", "")
    p.smallborough("Uhtna", "")
    p.village("Ubja", "")
    p.village("Toomla", "")
    p.village("Ussimäe", "")
    p.smallborough("Näpi", "")
    p.village("Roodevälja", "")
    p.village("Vaeküla", "")
    p.village("Kohala", "")
    p.village("Rägavere", "")
    p.village("Põlula", "")
    p.village("Nõmmise", "46710")
    p.village("Viru-Kabala", "46714")
    p.village("Miila", "46706")
    p.village("Sae", "46712")
    p.village("Kantküla", "46703")
    p.village("Kõrma", "46704")
    p.village("Nurkse", "46709")
    p.village("Lavi", "46705")
    p.village("Mõedaka", "46708")
    p.village("Ulvi", "46701")
    p.village("Aasuvälja", "46702")
    p.village("Uljaste", "46713")
    p.village("Männikvälja", "46707")

    p.village("Katku", "44214")
    p.village("Sämi-Tagaküla", "44225")
    p.village("Sooaluse", "44223")
    p.village("Jäätma", "")
    p.village("Kohala-Eesküla", "44216")
    p.village("Koovälja", "44217")
    p.village("Katela", "44213")
    p.village("Raudlepa", "44221")
    p.village("Sämi", "44224")
    p.village("Aluvere", "44208")
    p.village("Aresi", "44210")
    p.village("Kaarli", "44212")
    p.village("Nurme", "44219")
    p.village("Rahkla", "")
    p.village("Raudvere", "44222")
    p.village("Varudi-Altküla", "44228")
    p.village("Varudi-Vanaküla", "44229")
    p.village("Muru", "44218")
    p.village("Andja", "44209")
    p.village("Papiaru", "44206")

    p.municipality("Vihula", "")
    p.smallborough("Võsu", "")
    p.village("Käsmu", "")
    p.village("Sagadi", "")
    p.village("Võsupere", "")
    p.village("Palmse", "")
    p.village("Oandu", "")
    p.village("Metsiku", "45427")
    p.village("Annikvere", "45410")
    p.village("Ilumäe", "45414")
    p.village("Adaka", "45407")
    p.village("Kakuvälja", "45416")
    p.village("Villandi", "45449")
    p.village("Koolimäe", "45420")
    p.village("Natturi", "45430")
    p.village("Lahe", "45423")
    p.village("Joandu", "45415")
    p.village("Vila", "45448")
    p.village("Rutja", "45451")
    p.village("Metsanurga", "45426")
    p.village("Lauli", "45424")
    p.village("Altja", "45408")
    p.village("Pajuveski", "45434")
    p.village("Võhma", "")
    p.village("Karula", "45417")
    p.village("Noonu", "45431")
    p.village("Korjuse", "45421")
    p.village("Haili", "45413")
    p.village("Tepelvälja", "45440")
    p.village("Mustoja", "45429")
    p.village("Tõugu", "45444")
    p.village("Muike", "45428")
    p.village("Tidriku", "45441")
    p.village("Toolse", "45443")
    p.village("Eru", "45412")
    p.village("Pihlaspea", "45437")
    p.village("Salatse", "45439")
    p.village("Paasi", "45433")
    p.village("Tiigi", "45442")
    p.village("Lobi", "45425")
    p.village("Karepa", "45401")
    p.village("Aasumetsa", "45406")
    p.village("Andi", "45409")
    p.village("Kosta", "45422")
    p.village("Vainupea", "45446")
    p.village("Pedassaare", "45436")
    p.village("Koljaku", "45419")
    p.village("Vatku", "45447")
    p.village("Sakussaare", "45438")
    p.village("Uusküla", "45445")
    p.village("Kiva", "45418")
    p.village("Vergi", "45404")

    p.municipality("Haljala", "")
    p.village("Essu", "")
    p.village("Aaspere", "")
    p.village("Vanamõisa", "45319")
    p.village("Kandle", "45308")
    p.village("Pehka", "45315")
    p.village("Kärmu", "45311")
    p.village("Põdruse", "45316")
    p.village("Tatruse", "45318")
    p.village("Auküla", "45306")
    p.village("Kõldu", "45312")
    p.village("Kisuvere", "45310")
    p.village("Kavastu", "45309")
    p.village("Aasu", "45304")
    p.village("Lihulõpe", "45313")
    p.village("Võle", "45321")
    p.village("Idavere", "45307")
    p.village("Aaviku", "45305")
    p.village("Sauste", "45317")
    p.village("Liiguste", "45314")

    p.town("Kunda", "")
    p.municipality("Kadrina", "")
    p.village("Viitna", "")
    p.smallborough("Hulja", "")
    p.village("Tokolopi", "")
    p.village("Kadapiku", "")
    p.village("Tirbiku", "")
    p.village("Mõndavere", "45222")
    p.village("Võduvere", "45238")
    p.village("Kihlevere", "45215")
    p.village("Mäo", "45223")
    p.village("Põima", "45228")
    p.village("Vandu", "45237")
    p.village("Uku", "45234")
    p.village("Läsna", "45221")
    p.village("Vohnja", "45204")
    p.village("Ohepalu", "45225")
    p.village("Arbavere", "45206")
    p.village("Kiku", "45216")
    p.village("Vaiatu", "45236")
    p.village("Ama", "45205")
    p.village("Loobu", "45220")
    p.village("Udriku", "45233")
    p.village("Hõbeda", "45207")
    p.village("Rõmeda", "45230")
    p.village("Kallukse", "45214")
    p.village("Jõepere", "45209")
    p.village("Undla", "45235")
    p.village("Neeruti", "45224")
    p.village("Ridaküla", "45229")
    p.village("Lante", "45218")
    p.village("Võipere", "45239")
    p.village("Leikude", "45219")
    p.village("Härjadi", "45208")
    p.village("Orutaguse", "45226")
    p.village("Jõetaguse", "45210")
    p.village("Salda", "45231")
    p.village("Saukse", "45232")
    p.village("Pariisi", "45227")

    p.municipality("Laekvere", "")
    p.village("Muuga", "")
    p.village("Vassivere", "46519")
    p.village("Alekvere", "46505")
    p.village("Rajaküla", "46513")
    p.village("Kellavere", "46508")
    p.village("Salutaguse", "46516")
    p.village("Venevere", "46504")
    p.village("Rohu", "46515")
    p.village("Moora", "46510")
    p.village("Arukse", "46514")
    p.village("Kaasiksaare", "46507")
    p.village("Sirevere", "46517")
    p.village("Ilistvere", "46506")
    p.village("Padu", "46512")
    p.village("Luusika", "46509")
    p.village("Paasvere", "46511")

    p.municipality("Viru-Nigula", "")
    p.village("Siberi", "44028")
    p.village("Selja", "44027")
    p.village("Vasta", "44034")
    p.village("Kabeli", "44004")
    p.village("Kuura", "44012")
    p.village("Malla", "44016")
    p.village("Võrkla", "44035")
    p.village("Kaliküla", "44005")
    p.village("Samma", "44026")
    p.village("Ojaküla", "44020")
    p.village("Letipea", "44013")
    p.village("Nugeri", "44019")
    p.village("Linnuse", "44014")
    p.village("Pikaristi", "44024")
    p.village("Iila", "44003")
    p.village("Tüükri", "44031")
    p.village("Toomika", "44030")
    p.village("Kutsala", "44011")
    p.village("Kurna", "44010")
    p.village("Aasukalda", "44002")
    p.village("Mahu", "44015")
    p.village("Paasküla", "44021")
    p.village("Varudi", "44033")
    p.village("Pärna", "44025")
    p.village("Simunamäe", "44029")
    p.village("Pada", "44023")
    p.village("Pada-Aruküla", "44022")
    p.village("Villavere", "44037")
    p.village("Kanguristi", "44006")
    p.village("Marinu", "44017")
    p.village("Metsavälja", "44018")
    p.village("Kiviküla", "44007")
    p.village("Unukse", "44032")

    p.municipality("Eisma", "")

