# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Saare (county)
    p.county("Saare", "")
    p.municipality("Leisi", "")
    p.village("Parasmetsa", "94241")
    p.village("Hiievälja", "94231")
    p.village("Triigi", "94243")
    p.village("Lõpi", "94255")
    p.village("Luulupe", "94251")
    p.village("Metsküla", "94271")
    p.village("Asuka", "94257")
    p.village("Paaste", "94240")
    p.village("Moosi", "94236")
    p.village("Jõiste", "94232")
    p.village("Angla", "94244")
    p.village("Purtsa", "94264")
    p.village("Mätja", "94214")
    p.village("Laugu", "94233")
    p.village("Kopli", "94249")
    p.village("Tareste", "94216")
    p.village("Linnaka", "94213")
    p.village("Tõre", "94217")
    p.village("Pöitse", "94259")
    p.village("Poka", "94258")
    p.village("Tiitsuotsa", "94265")
    p.village("Veske", "94247")
    p.village("Nihatu", "94215")
    p.village("Ratla", "94223")
    p.village("Nurme", "")
    p.village("Õeste", "94219")
    p.village("Külma", "94211")
    p.village("Nava", "94252")
    p.village("Metsaääre", "94222")
    p.village("Roobaka", "94242")
    p.village("Mujaste", "94237")
    p.village("Räägi", "94225")
    p.village("Aru", "94245")
    p.village("Koiduvälja", "94261")
    p.village("Oitme", "94239")
    p.village("Murika", "94272")
    p.village("Selja", "94256")
    p.village("Koikla", "94221")
    p.village("Meiuste", "94235")
    p.village("Pammana", "94273")
    p.village("Täätsi", "94224")
    p.village("Aruste", "94212")
    p.village("Tutku", "94250")
    p.village("Peederga", "94246")
    p.village("Soela", "94274")
    p.village("Pärsama", "94201")
    p.village("Pamma", "94263")
    p.village("Karja", "94248")
    p.village("Kaisa", "94254")

    p.municipality("Salme", "")
    p.village("Rahuste", "93235")
    p.village("Lõu", "93234")
    p.village("Kaimri", "93232")
    p.village("Anseküla", "93211")
    p.village("Üüdibe", "93224")
    p.village("Imara", "93213")
    p.village("Metsalõuka", "93218")
    p.village("Hindu", "")
    p.village("Järve", "93271")
    p.village("Tiirimetsa", "93223")
    p.village("Länga", "93215")
    p.village("Tehumardi", "93222")
    p.village("Kaugatoma", "93233")
    p.village("Toomalõuka", "93261")
    p.village("Lahetaguse", "93260")
    p.village("Läätsa", "93216")
    p.village("Möldri", "93220")
    p.village("Lõmala", "93217")
    p.village("Suurna", "93221")
    p.village("Lassi", "93214")
    p.village("Easte", "93212")
    p.village("Vintri", "93237")

    p.municipality("Kaarma", "")
    p.smallborough("Aste", "")
    p.smallborough("Nasva", "")
    p.smallborough("Kudjape", "")
    p.village("Mändjala", "")
    p.village("Muratsi", "")
    p.village("Praakli", "")
    p.village("Laheküla", "")
    p.village("Kirikuküla", "")
    p.village("Sikassaare", "")
    p.village("Upa", "")
    p.village("Vaivere", "")
    p.village("Randvere", "")
    p.village("Abruka", "93826")
    p.village("Kaisvere", "93733")
    p.village("Kiratsi", "93741")
    p.village("Tamsalu", "93840")
    p.village("Hübja", "93715")
    p.village("Õha", "93888")
    p.village("Tõrise", "93886")
    p.village("Parila", "93836")
    p.village("Anijala", "93831")
    p.village("Lilbi", "93853")
    p.village("Kellamäe", "93723")
    p.village("Asuküla", "93717")
    p.village("Ansi", "93832")
    p.village("Kungla", "")
    p.village("Hakjala", "93714")
    p.village("Paimala", "93855")
    p.village("Jootme", "93722")
    p.village("Vantri", "93716")
    p.village("Pähkla", "93874")
    p.village("Eikla", "93881")
    p.village("Tõru", "93887")
    p.village("Tõlli", "93841")
    p.village("Endla", "93712")
    p.village("Meedla", "93744")
    p.village("Vestla", "93746")
    p.village("Koidu", "93834")
    p.village("Mullutu", "93835")
    p.village("Piila", "93885")
    p.village("Viira", "")
    p.village("Aula-Vintri", "93711")
    p.village("Kuke", "93734")
    p.village("Käku", "93753")
    p.village("Koidula", "93884")
    p.village("Pärni", "93837")
    p.village("Irase", "93721")
    p.village("Maleva", "93743")
    p.village("Tahula", "93856")
    p.village("Uduvere", "93745")
    p.village("Kasti", "93858")
    p.village("Laadjala", "93742")
    p.village("Kärdu", "")
    p.village("Nõmme", "")
    p.village("Kaarmise", "93833")
    p.village("Haamse", "93713")
    p.village("Laoküla", "93754")
    p.village("Kaubi", "93882")
    p.village("Unimäe", "93875")
    p.village("Vatsküla", "93891")
    p.village("Keskranna", "93890")
    p.village("Saia", "93725")

    p.municipality("Orissaare", "")
    p.village("Pulli", "94612")
    p.village("Tagavere", "94638")
    p.village("Põripõllu", "94613")
    p.village("Randküla", "94656")
    p.village("Imavere", "94623")
    p.village("Mäeküla", "94632")
    p.village("Järveküla", "94654")
    p.village("Maasi", "94630")
    p.village("Ariste", "")
    p.village("Võhma", "")
    p.village("Taaliku", "94637")
    p.village("Suur-Pahila", "94659")
    p.village("Kalma", "94624")
    p.village("Väljaküla", "")
    p.village("Kõinastu", "94611")
    p.village("Arju", "94622")
    p.village("Kavandi", "94655")
    p.village("Väike-Pahila", "94660")
    p.village("Väike-Rahula", "94640")
    p.village("Kareda", "94625")
    p.village("Saikla", "94634")
    p.village("Raugu", "94658")
    p.village("Tumala", "94639")
    p.village("Mehama", "94631")
    p.village("Orinõmme", "94633")
    p.village("Ööriku", "94642")
    p.village("Salu", "94635")
    p.village("Jaani", "94653")
    p.village("Suur-Rahula", "94636")
    p.village("Haapsu", "94651")
    p.village("Liigalaskma", "94628")
    p.village("Kuninguste", "94626")

    p.municipality("Kärla", "")
    p.village("Sõmera", "")
    p.village("Paiküla", "93562")
    p.village("Kulli", "")
    p.village("Mõnnuste", "93512")
    p.village("Nõmpa", "93846")
    p.village("Vendise", "93848")
    p.village("Kõrkküla", "93527")
    p.village("Hirmuste", "93523")
    p.village("Kogula", "")
    p.village("Ulje", "93529")
    p.village("Käesla", "93526")
    p.village("Kuuse", "93551")
    p.village("Arandi", "93521")
    p.village("Jõempa", "93844")
    p.village("Mätasselja", "93520")
    p.village("Paevere", "93528")
    p.village("Kandla", "93845")
    p.village("Vennati", "93530")
    p.village("Anepesa", "93843")
    p.village("Karida", "93524")
    p.village("Sauvere", "93847")

    p.municipality("Kihelkonna", "")
    p.village("Loona", "")
    p.village("Viki", "")
    p.village("Oju", "")
    p.village("Rootsiküla", "")
    p.village("Karujärve", "")
    p.village("Kuralase", "")
    p.village("Tammese", "93449")
    p.village("Abula", "93461")
    p.village("Virita", "93414")
    p.village("Odalätsi", "93468")
    p.village("Üru", "93471")
    p.village("Kiirassaare", "93433")
    p.village("Läägi", "93456")
    p.village("Kurevere", "93439")
    p.village("Kuusiku", "")
    p.village("Neeme", "93444")
    p.village("Kõõru", "93467")
    p.village("Pidula", "93469")
    p.village("Pajumõisa", "93412")
    p.village("Kõruse", "93440")
    p.village("Tagamõisa", "93448")
    p.village("Vedruka", "93432")
    p.village("Sepise", "93447")
    p.village("Kalmu", "93436")
    p.village("Kuremetsa", "93464")
    p.village("Kuumi", "93465")
    p.village("Vaigu", "93452")
    p.village("Lätiniidi", "93441")
    p.village("Vilsandi", "93421")
    p.village("Undva", "93451")
    p.village("Tohku", "93450")
    p.village("Varkja", "93470")
    p.village("Abaja", "93411")
    p.village("Kehila", "93437")
    p.village("Kotsma", "93434")

    p.town("Kuressaare", "")
    p.municipality("Valjala", "")
    p.village("Põlluküla", "")
    p.village("Oessaare", "94313")
    p.village("Kõriska", "94338")
    p.village("Tõnija", "94344")
    p.village("Vanalõve", "94318")
    p.village("Vilidu", "94347")
    p.village("Jööri", "94332")
    p.village("Võrsna", "94323")
    p.village("Kalju", "94333")
    p.village("Jursi", "94321")
    p.village("Kuiste", "94336")
    p.village("Kalli", "94322")
    p.village("Veeriku", "94346")
    p.village("Männiku", "94340")
    p.village("Kallemäe", "94301")
    p.village("Koksi", "94335")
    p.village("Undimäe", "94345")
    p.village("Röösa", "94343")
    p.village("Siiksaare", "94316")
    p.village("Jõelepa", "94331")
    p.village("Rahu", "94342")
    p.village("Turja", "94317")
    p.village("Väkra", "94348")
    p.village("Lööne", "94339")
    p.village("Sakla", "94315")

    p.municipality("Lümanda", "")
    p.village("Himmiste", "93311")
    p.village("Koki", "93327")
    p.village("Koovi", "93314")
    p.village("Atla", "93322")
    p.village("Kipi", "93313")
    p.village("Vahva", "93319")
    p.village("Viidu", "93343")
    p.village("Leedri", "93316")
    p.village("Kotlandi", "93328")
    p.village("Kuusnõmme", "93342")
    p.village("Karala", "93325")
    p.village("Austla", "93323")
    p.village("Taritu", "93331")
    p.village("Vana-Lahetaguse", "93320")
    p.village("Varpe", "93321")
    p.village("Riksu", "93330")
    p.village("Jõgela", "93312")
    p.village("Eeriksaare", "93324")
    p.village("Metsapere", "93329")
    p.village("Koimla", "93326")

    p.municipality("Pöide", "")
    p.village("Tornimäe", "")
    p.village("Muraja", "")
    p.village("Veere", "")
    p.village("Kanissaare", "94533")
    p.village("Unguma", "94545")
    p.village("Reina", "94553")
    p.village("Kübassaare", "94534")
    p.village("Kakuna", "94532")
    p.village("Sundimetsa", "94521")
    p.village("Kõrkvere", "94535")
    p.village("Mui", "94543")
    p.village("Ula", "")
    p.village("Ardla", "94531")
    p.village("Are", "94511")
    p.village("Metsara", "94551")
    p.village("Oti", "94518")
    p.village("Keskvere", "")
    p.village("Välta", "94540")
    p.village("Neemi", "94537")
    p.village("Koigi", "94515")
    p.village("Talila", "94538")
    p.village("Uuemõisa", "94522")
    p.village("Levala", "94517")
    p.village("Nenu", "94552")
    p.village("Kahutsi", "94513")
    p.village("Kärneri", "94542")
    p.village("Puka", "94519")
    p.village("Iruste", "94512")

    p.municipality("Pihtla", "")
    p.village("Kaali", "")
    p.village("Suure-Rootsi", "")
    p.village("Kõljala", "")
    p.village("Püha", "94117")
    p.village("Reeküla", "94148")
    p.village("Metsaküla", "")
    p.village("Hämmelepa", "94111")
    p.village("Kõnnu", "")
    p.village("Tõlluste", "94124")
    p.village("Nässuma", "94116")
    p.village("Haeska", "94142")
    p.village("Matsiranna", "94154")
    p.village("Reo", "94171")
    p.village("Räimaste", "94120")
    p.village("Sepa", "")
    p.village("Sutu", "94123")
    p.village("Eiste", "94141")
    p.village("Masa", "94146")
    p.village("Kiritu", "94113")
    p.village("Ennu", "94126")
    p.village("Iilaste", "94112")
    p.village("Sagariste", "94149")
    p.village("Sauaru", "94122")
    p.village("Saue-Putla", "94151")
    p.village("Väike-Rootsi", "94131")
    p.village("Salavere", "94150")
    p.village("Rahniku", "94118")
    p.village("Kangrusselja", "94153")
    p.village("Kailuka", "94127")
    p.village("Ilpla", "94161")
    p.village("Leina", "94115")
    p.village("Liiva-Putla", "94145")
    p.village("Sandla", "94121")

    p.municipality("Torgu", "")
    p.village("Läbara", "")
    p.village("Iide", "")
    p.village("Kaavi", "93239")
    p.village("Lindmetsa", "93243")
    p.village("Mäebe", "")
    p.village("Mõntu", "93122")
    p.village("Lõupõllu", "93245")
    p.village("Mässa", "93247")
    p.village("Sääre", "93249")
    p.village("Maantee", "93121")
    p.village("Soodevahe", "93114")
    p.village("Karuste", "93241")
    p.village("Tammuna", "93250")
    p.village("Jämaja", "93238")
    p.village("Ohessaare", "93248")
    p.village("Kaunispe", "93242")
    p.village("Laadla", "93112")
    p.village("Kargi", "93240")
    p.village("Hänga", "93111")
    p.village("Lülle", "93113")
    p.village("Türju", "93251")

    p.municipality("Mustjala", "")
    p.village("Merise", "")
    p.village("Silla", "")
    p.village("Rahtla", "93614")
    p.village("Kugalepa", "93611")
    p.village("Küdema", "93622")
    p.village("Selgase", "93642")
    p.village("Jauni", "93641")
    p.village("Ohtja", "93623")
    p.village("Tuiu", "93645")
    p.village("Tagaranna", "93616")
    p.village("Kiruma", "93621")
    p.village("Paatsa", "93644")
    p.village("Vanakubja", "93617")
    p.village("Panga", "93634")
    p.village("Pahapilli", "93633")
    p.village("Ninase", "93613")
    p.village("Järise", "93643")
    p.village("Liiküla", "93631")

    p.municipality("Laimjala", "")
    p.village("Rannaküla", "")
    p.village("Aaviku", "94417")
    p.village("Käo", "94434")
    p.village("Mustla", "")
    p.village("Asva", "94418")
    p.village("Üüvere", "94425")
    p.village("Paju-Kurdla", "94415")
    p.village("Saaremetsa", "94443")
    p.village("Audla", "94431")
    p.village("Kapra", "94432")
    p.village("Kõiguste", "94421")
    p.village("Jõe", "")
    p.village("Saareküla", "94442")
    p.village("Mägi-Kurdla", "94412")
    p.village("Ridala", "94416")
    p.village("Pahavalla", "94414")
    p.village("Kahtla", "94420")
    p.village("Kingli", "94433")
    p.village("Viltina", "94424")
    p.village("Ruhve", "94423")

    p.municipality("Muhu", "")
    p.village("Liiva", "")
    p.village("Rinsi", "94761")
    p.village("Vanamõisa", "")
    p.village("Tamse", "94763")
    p.village("Igaküla", "94722")
    p.village("Pallasmaa", "94754")
    p.village("Päelda", "94755")
    p.village("Koguva", "94724")
    p.village("Kantsi", "94723")
    p.village("Lehtmetsa", "94746")
    p.village("Võiküla", "94713")
    p.village("Simisti", "94719")
    p.village("Nautse", "94728")
    p.village("Levalõpme", "94748")
    p.village("Linnuse", "")
    p.village("Mõega", "94711")
    p.village("Kapi", "94743")
    p.village("Raugi", "94759")
    p.village("Mõisaküla", "")
    p.village("Kuivastu", "94702")
    p.village("Külasema", "94744")
    p.village("Leeskopa", "94726")
    p.village("Vahtraste", "94765")
    p.village("Rässa", "94718")
    p.village("Raegma", "94717")
    p.village("Lõetsa", "94749")
    p.village("Pädaste", "94716")
    p.village("Kallaste", "")
    p.village("Kesse", "94720")
    p.village("Pärase", "94756")
    p.village("Lalli", "94745")
    p.village("Oina", "94715")
    p.village("Ridasi", "94731")
    p.village("Soonda", "94762")
    p.village("Tupenurme", "94764")
    p.village("Piiri", "94730")
    p.village("Mäla", "94750")
    p.village("Paenase", "94753")
    p.village("Suuremõisa", "94733")
    p.village("Põitse", "94757")
    p.village("Tusti", "94712")
    p.village("Lepiku", "94747")
    p.village("Hellamaa", "94741")
    p.village("Rootsivere", "94732")
    p.village("Võlla", "94714")
    p.village("Rebaski", "94760")
    p.village("Aljava", "94721")
    p.village("Nõmmküla", "94752")

    p.municipality("Ruhnu", "")

