# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    
    # Ida-Viru (county)
    p.county("Ida-Viru", "")
    p.municipality("Lohusuu", "")
    p.village("Kalmaküla", "")
    p.village("Ninasi", "42003")
    p.village("Tammispää", "42006")
    p.village("Raadna", "42004")
    p.village("Kärasi", "42119")
    p.village("Piilsi", "42120")
    p.village("Jõemetsa", "42118")
    p.village("Separa", "42005")
    p.village("Vilusi", "42007")

    p.municipality("Sonda", "")
    p.smallborough("Erra", "")
    p.village("Erra-Liiva", "")
    p.village("Varinurme", "")
    p.village("Vana-Sonda", "43006")
    p.village("Uljaste", "43005")
    p.village("Koljala", "43135")
    p.village("Vainu", "43136")
    p.village("Ilmaste", "43138")
    p.village("Nüri", "43003")
    p.village("Satsu", "43004")

    p.municipality("Toila", "")
    p.smallborough("Voka", "")
    p.village("Pühajõe", "")
    p.village("Altküla", "")
    p.village("Konju", "41714")
    p.village("Uikala", "41717")
    p.village("Martsa", "41715")
    p.village("Päite", "40104")
    p.village("Metsamägara", "41712")
    p.village("Vaivina", "40105")

    p.municipality("Tudulinna", "")
    p.village("Sahargu", "")
    p.village("Pikati", "42207")
    p.village("Rannapungerja", "42208")
    p.village("Roostoja", "42209")
    p.village("Peressaare", "42121")
    p.village("Oonurme", "42206")
    p.village("Tagajõe", "42211")
    p.village("Lemmaku", "42205")
    p.village("Kellassaare", "42204")

    p.town("Sillamäe", "")
    p.town("Püssi", "")
    p.municipality("Lüganuse", "")
    p.village("Purtse", "")
    p.village("Matka", "")
    p.village("Moldova", "43307")
    p.village("Irvala", "43132")
    p.village("Mustmätta", "43308")
    p.village("Aa", "43311")
    p.village("Jabara", "43304")
    p.village("Kopli", "43305")
    p.village("Liimala", "43306")
    p.village("Varja", "43309")
    p.village("Voorepera", "43310")
    p.village("Lohkuse", "43225")

    p.municipality("Vaivara", "")
    p.smallborough("Sinimäe", "")
    p.smallborough("Olgina", "")
    p.village("Tõrvajõe", "")
    p.village("Sõtke", "")
    p.village("Hiiemetsa", "40108")
    p.village("Udria", "40118")
    p.village("Soldina", "40115")
    p.village("Vodava", "40119")
    p.village("Perjatsi", "40241")
    p.village("Pimestiku", "40113")
    p.village("Hundinurga", "40109")
    p.village("Auvere", "40107")
    p.village("Arumäe", "40106")
    p.village("Kudruküla", "29024")
    p.village("Mustanina", "40111")
    p.village("Laagna", "40110")
    p.village("Puhkova", "40114")
    p.village("Meriküla", "29025")
    p.village("Peeterristi", "40112")

    p.town("Narva", "")
    p.municipality("Avinurme", "")
    p.village("Paadenurme", "42113")
    p.village("Laekannu", "42110")
    p.village("Tammessaare", "42115")
    p.village("Adraku", "42103")
    p.village("Vadi", "42116")
    p.village("Kiissa", "42106")
    p.village("Kõrve", "42107")
    p.village("Sälliksaare", "42114")
    p.village("Kaevussaare", "42122")
    p.village("Kõrvemetsa", "42108")
    p.village("Maetsma", "42112")
    p.village("Kõveriku", "42109")
    p.village("Alekere", "42104")
    p.village("Lepiksaare", "42111")
    p.village("Änniksaare", "42117")
    p.village("Ulvi", "42102")

    p.town("Narva-Jõesuu", "")
    p.town("Kohtla-Järve", "")
    p.township("Sirgala (Viivikonna linnaosa)", "")
    p.municipality("Aseri", "")
    p.village("Rannu", "")
    p.village("Kestla", "43303")
    p.village("Kõrkküla", "43405")
    p.village("Kõrtsialuse", "43406")
    p.village("Kalvi", "43403")
    p.village("Oru", "43407")
    p.village("Koogu", "43404")
    p.village("Aseriaru", "43402")

    p.town("Jõhvi", "")
    p.village("Puru", "")
    p.village("Linna", "")
    p.smallborough("Tammiku", "")
    p.village("Edise", "")
    p.village("Kotinuka", "")
    p.village("Sompa", "")
    p.village("Pauliku", "")
    p.village("Kahula", "")
    p.village("Pajualuse", "")
    p.village("Pargitaguse", "")
    p.village("Kose", "")

    p.municipality("Iisaku", "")
    p.village("Kuru", "")
    p.village("Tammetaguse", "41112")
    p.village("Sõrumäe", "41111")
    p.village("Jõuga", "41104")
    p.village("Alliku", "41102")
    p.village("Lõpe", "42213")
    p.village("Koldamäe", "41106")
    p.village("Taga-Roostoja", "42203")
    p.village("Kauksi", "41008")
    p.village("Pootsiku", "41109")
    p.village("Kasevälja", "41105")
    p.village("Sälliku", "41110")
    p.village("Varesmetsa", "41115")
    p.village("Lipniku", "41107")
    p.village("Vaikla", "41114")
    p.village("Tärivere", "41113")
    p.village("Imatu", "41103")

    p.town("Kiviõli", "")
    p.municipality("Alajõe", "")
    p.village("Smolnitsa", "")
    p.village("Remniku", "")
    p.village("Vasknarva", "")
    p.village("Katase", "")
    p.village("Karjamaa", "41002")
    p.village("Uusküla", "41006")

    p.municipality("Kohtla-Nõmme", "")
    p.municipality("Maidla", "")
    p.village("Savala", "")
    p.village("Uniküla", "")
    p.village("Soonurme", "")
    p.village("Aidu-Liiva", "")
    p.village("Kulja", "42311")
    p.village("Mehide", "42313")
    p.village("Virunurme", "42324")
    p.village("Rebu", "42317")
    p.village("Tarumaa", "41305")
    p.village("Lümatu", "42312")
    p.village("Aidu", "42302")
    p.village("Aidu-Nõmme", "42304")
    p.village("Koolma", "42310")
    p.village("Arupäälse", "42307")
    p.village("Aidu-Sooküla", "42305")
    p.village("Lipu", "41304")
    p.village("Rääsa", "42318")
    p.village("Salaküla", "43133")
    p.village("Aruküla", "")
    p.village("Sirtsi", "42320")
    p.village("Piilse", "42316")
    p.village("Hirmuse", "42309")
    p.village("Ojamaa", "42315")
    p.village("Veneoja", "42323")
    p.village("Aruvälja", "42308")
    p.village("Oandu", "42314")

    p.municipality("Mäetaguse", "")
    p.village("Kiikla", "")
    p.village("Rajaküla", "")
    p.village("Liivakünka", "41314")
    p.village("Uhe", "41320")
    p.village("Apandiku", "41306")
    p.village("Väike-Pungerja", "41324")
    p.village("Atsalama", "41309")
    p.village("Võhma", "41321")
    p.village("Ratva", "41318")
    p.village("Kalina", "41312")
    p.village("Ereda", "41310")
    p.village("Tarakuse", "41319")
    p.village("Võide", "41322")
    p.village("Metsküla", "41315")
    p.village("Arvila", "41308")
    p.village("Pagari", "41303")
    p.village("Jõetaguse", "41311")
    p.village("Võrnu", "41323")

    p.municipality("Kohtla", "")
    p.village("Roodu", "")
    p.village("Servaääre", "30506")
    p.village("Paate", "30625")
    p.village("Kabelimetsa", "30624")
    p.village("Järve", "30331")
    p.village("Täkumetsa", "30626")
    p.village("Vitsiku", "30507")
    p.village("Ontika", "41556")
    p.village("Saka", "30103")
    p.village("Mõisamaa", "30332")
    p.village("Kukruse", "30623")
    p.village("Amula", "41553")
    p.village("Kaasikaia", "41554")
    p.village("Kaasikvälja", "41555")
    p.village("Peeri", "30333")
    p.village("Valaste", "41557")

    p.municipality("Illuka", "")
    p.village("Kurtna", "")
    p.village("Kuremäe", "")
    p.village("Konsu", "41209")
    p.village("Kivinõmme", "41208")
    p.village("Rausvere", "41214")
    p.village("Karoli", "41011")
    p.village("Permisküla", "41013")
    p.village("Agusalu", "41211")
    p.village("Ohakvere", "41210")
    p.village("Kaatermu", "41205")
    p.village("Puhatu", "41213")
    p.village("Kamarna", "41207")
    p.village("Jaama", "41010")
    p.village("Edivere", "41203")
    p.village("Vasavere", "41215")
    p.village("Kuningaküla", "41012")
    p.village("Kaidma", "41206")
    p.village("Ongassaare", "41212")


