# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    
    # Lääne (county)
    p.county("Lääne", "")
    p.town("Lihula", "")
    p.village("Hälvati", "")
    p.village("Tuudi", "")
    p.village("Kirbla", "")
    p.village("Penijõe", "90305")
    p.village("Seira", "90214")
    p.village("Kloostri", "90206")
    p.village("Parivere", "90228")
    p.village("Lautna", "90212")
    p.village("Võhma", "90215")
    p.village("Matsalu", "90230")
    p.village("Petaaluse", "90223")
    p.village("Rumba", "90213")
    p.village("Vagivere", "90226")
    p.village("Metsküla", "90232")
    p.village("Tuhu", "90225")
    p.village("Valuste", "90227")
    p.village("Kirikuküla", "90221")
    p.village("Poanse", "90224")
    p.village("Meelva", "90231")
    p.village("Kelu", "90205")
    p.village("Alaküla", "90219")
    p.village("Kunila", "90222")
    p.village("Pagasi", "90207")
    p.village("Saastna", "90233")
    p.village("Järise", "90220")

    p.municipality("Risti", "")
    p.village("Jaakna", "90911")
    p.village("Kuijõe", "90903")
    p.village("Piirsalu", "90902")
    p.village("Rõuma", "90904")

    p.municipality("Ridala", "")
    p.smallborough("Uuemõisa", "")
    p.smallborough("Paralepa", "")
    p.village("Valgevälja", "")
    p.village("Herjava", "")
    p.village("Tanska", "")
    p.village("Vilkla", "")
    p.village("Rohuküla", "")
    p.village("Nõmme", "")
    p.village("Mäeküla", "")
    p.village("Pusku", "")
    p.village("Kiltsi", "")
    p.village("Sinalepa", "")
    p.village("Saardu", "90424")
    p.village("Lannuste", "90414")
    p.village("Liivaküla", "")
    p.village("Metsaküla", "90436")
    p.village("Allika", "90405")
    p.village("Üsse", "90461")
    p.village("Tuuru", "90426")
    p.village("Põgari-Sassi", "90421")
    p.village("Kiideva", "90409")
    p.village("Rohense", "90457")
    p.village("Tammiku", "")
    p.village("Jõõdre", "90412")
    p.village("Hobulaiu", "90432")
    p.village("Vätse", "90481")
    p.village("Parila", "90418")
    p.village("Emmuvere", "90431")
    p.village("Kadaka", "90455")
    p.village("Väike-Ahli", "90446")
    p.village("Koheri", "90434")
    p.village("Koidu", "90410")
    p.village("Rummu", "90458")
    p.village("Haeska", "90407")
    p.village("Kolila", "90411")
    p.village("Kaevere", "90408")
    p.village("Mägari", "90438")
    p.village("Suure-Ahli", "90443")
    p.village("Aamse", "90450")
    p.village("Käpla", "90413")
    p.village("Erja", "90451")
    p.village("Litu", "90416")
    p.village("Kolu", "90435")
    p.village("Varni", "90445")
    p.village("Puise", "90420")
    p.village("Espre", "90452")
    p.village("Ammuta", "90406")
    p.village("Laheva", "90456")
    p.village("Uneste", "90427")
    p.village("Lõbe", "90417")
    p.village("Sepaküla", "90442")
    p.village("Puiatu", "90419")
    p.village("Kabrametsa", "90454")
    p.village("Saanika", "90423")
    p.village("Võnnu", "90460")
    p.village("Kiviküla", "90433")
    p.village("Panga", "90402")

    p.town("Haapsalu", "")
    p.municipality("Hanila", "")
    p.smallborough("Virtsu", "")
    p.village("Voose", "")
    p.village("Kõmsi", "")
    p.village("Rame", "90127")
    p.village("Rannaküla", "")
    p.village("Massu", "90111")
    p.village("Ullaste", "90117")
    p.village("Pajumaa", "90125")
    p.village("Kokuta", "90108")
    p.village("Vatla", "90103")
    p.village("Karuse", "90112")
    p.village("Mäense", "90113")
    p.village("Linnuse", "90121")
    p.village("Kõera", "90110")
    p.village("Kaseküla", "90106")
    p.village("Esivere", "90104")
    p.village("Ridase", "90131")
    p.village("Äila", "90128")
    p.village("Pivarootsi", "90126")
    p.village("Lõo", "90122")
    p.village("Nehatu", "90123")
    p.village("Kiska", "90120")
    p.village("Kuke", "90109")
    p.village("Kause", "90107")
    p.village("Nurmsi", "90124")
    p.village("Kinksi", "90130")
    p.village("Salevere", "90116")

    p.municipality("Taebla", "")
    p.smallborough("Palivere", "")
    p.village("Luigu", "")
    p.village("Vidruka", "")
    p.village("Nigula", "")
    p.village("Pälli", "")
    p.village("Väänla", "90819")
    p.village("Võntküla", "90820")
    p.village("Allikmaa", "90811")
    p.village("Nihka", "90808")
    p.village("Koela", "90806")
    p.village("Leediküla", "90813")
    p.village("Kedre", "90812")
    p.village("Kadarpiku", "90804")
    p.village("Kirimäe", "90805")
    p.village("Tagavere", "90816")
    p.village("Turvalepa", "90817")

    p.municipality("Oru", "")
    p.village("Linnamäe", "")
    p.village("Saunja", "")
    p.village("Niibi", "91015")
    p.village("Jalukse", "91004")
    p.village("Ingküla", "91003")
    p.village("Soolu", "91012")
    p.village("Auaste", "91002")
    p.village("Seljaküla", "91011")
    p.village("Mõisaküla", "")
    p.village("Kärbla", "91006")
    p.village("Keedika", "91005")
    p.village("Uugla", "91013")
    p.village("Salajõe", "91016")
    p.village("Vedra", "91014")

    p.municipality("Vormsi", "")
    p.village("Hullo", "")
    p.village("Sviby", "91313")
    p.village("Söderby", "91314")
    p.village("Rälby", "91310")
    p.village("Saxby", "91311")
    p.village("Norrby", "91308")
    p.village("Rumpo", "91309")
    p.village("Kersleti", "91307")
    p.village("Förby", "91305")
    p.village("Borrby", "91302")
    p.village("Suuremõisa", "91312")
    p.village("Fällarna", "91304")
    p.village("Diby", "91303")

    p.municipality("Martna", "")
    p.village("Rõude", "")
    p.village("Kaasiku", "")
    p.village("Niinja", "90628")
    p.village("Oonga", "90616")
    p.village("Ehmja", "90620")
    p.village("Uusküla", "90634")
    p.village("Väike-Lähtru", "90636")
    p.village("Soo-otsa", "90646")
    p.village("Enivere", "90621")
    p.village("Keskküla", "90606")
    p.village("Kokre", "90626")
    p.village("Kirna", "90625")
    p.village("Keskvere", "90642")
    p.village("Ohtla", "90630")
    p.village("Tuka", "90617")
    p.village("Kaare", "90640")
    p.village("Putkaste", "90631")
    p.village("Kabeli", "90641")
    p.village("Jõesse", "90622")
    p.village("Laiküla", "90612")
    p.village("Kasari", "90605")
    p.village("Keravere", "90614")
    p.village("Kurevere", "90643")
    p.village("Kuluse", "90627")
    p.village("Suure-Lähtru", "90632")
    p.village("Männiku", "90644")
    p.village("Allikotsa", "90613")
    p.village("Rannajõe", "90645")
    p.village("Kesu", "90624")

    p.municipality("Noarootsi", "")
    p.village("Spithami", "")
    p.village("Pürksi", "")
    p.village("Suur-Nõmmküla", "91232")
    p.village("Saare", "91205")
    p.village("Rooslepa", "91219")
    p.village("Einbi", "91203")
    p.village("Väike-Nõmmküla", "91233")
    p.village("Telise/Tällnäs", "91208")
    p.village("Elbiku", "91202")
    p.village("Paslepa/Pasklepi", "91204")
    p.village("Sutlepa", "91230")
    p.village("Dirhami", "91214")
    p.village("Hosby", "")
    p.village("Vanaküla", "")
    p.village("Aulepa", "91231")
    p.village("Tahu", "91206")
    p.village("Kudani/Gutanäsi", "91216")
    p.village("Hara", "91211")
    p.village("Höbringi", "91213")
    p.village("Tuksi", "91221")
    p.village("Riguldi", "91218")
    p.village("Osmussaare", "91217")
    p.village("Österby", "91207")

    p.municipality("Nõva", "")
    p.village("Hindaste", "91102")
    p.village("Peraküla", "91114")
    p.village("Variku", "91106")
    p.village("Vaisi", "91105")
    p.village("Tusari", "91112")
    p.village("Nõmmemaa", "91103")

    p.municipality("Kullamaa", "")
    p.village("Koluvere", "")
    p.village("Lemmikküla", "90714")
    p.village("Jõgisoo", "90710")
    p.village("Ubasalu", "90719")
    p.village("Kullametsa", "90713")
    p.village("Üdruma", "90720")
    p.village("Silla", "90718")
    p.village("Päri", "90717")
    p.village("Kalju", "90703")
    p.village("Kastja", "90715")
    p.village("Mõrdu", "90716")
    p.village("Leila", "90704")
    p.village("Liivi", "90711")


