# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Tartu (county)
    p.county("Tartu", "")
    p.town("Tartu", "")
    p.smallborough("Kõrveküla", "")
    p.smallborough("Vahi", "")
    p.village("Lombi", "")
    p.smallborough("Lähte", "")
    p.village("Maramaa", "")
    p.village("Tila", "")
    p.village("Haava", "")
    p.village("Aovere", "")
    p.village("Vasula", "")
    p.village("Vesneri", "")
    p.smallborough("Äksi", "")
    p.village("Kastli", "60508")
    p.village("Salu", "60525")
    p.village("Soitsjärve", "60527")
    p.village("Sojamaa", "60528")
    p.village("Igavere", "60506")
    p.village("Jõusa", "60507")
    p.village("Võibla", "60540")
    p.village("Pupastvere", "60523")
    p.village("Kobratu", "60510")
    p.village("Väägvere", "60541")
    p.village("Kukulinna", "60511")
    p.village("Tammistu", "60531")
    p.village("Õvi", "60542")
    p.village("Kükitaja", "60514")
    p.village("Vedu", "60536")
    p.village("Arupää", "60504")
    p.village("Sootaga", "60529")
    p.village("Erala", "60505")
    p.village("Toolamaa", "60533")
    p.village("Kikivere", "60509")
    p.village("Viidike", "60538")
    p.village("Nõela", "60521")
    p.village("Lammiku", "60515")
    p.village("Möllatsi", "60519")
    p.village("Puhtaleiva", "60522")
    p.village("Saadjärve", "60524")
    p.village("Vilussaare", "60539")
    p.village("Kärkna", "60513")
    p.village("Soeküla", "60526")
    p.village("Metsanuka", "60518")
    p.village("Nigula", "60520")
    p.village("Taabri", "60530")

    p.municipality("Luunja", "")
    p.village("Lohkva", "")
    p.village("Veibri", "")
    p.village("Kabina", "")
    p.village("Rõõmu", "")
    p.village("Kakumetsa", "")
    p.village("Põvvatu", "")
    p.village("Sava", "62214")
    p.village("Pajukurmu", "62209")
    p.village("Savikoja", "62215")
    p.village("Pilka", "")
    p.village("Poksi", "62211")
    p.village("Sääsekõrva", "62218")
    p.village("Kikaste", "62205")
    p.village("Kõivu", "62206")
    p.village("Sirgumetsa", "62217")
    p.village("Viira", "62221")
    p.village("Muri", "62208")
    p.village("Kavastu", "62204")
    p.village("Sääsküla", "62219")
    p.village("Sirgu", "62216")

    p.municipality("Ülenurme", "")
    p.smallborough("Tõrvandi", "")
    p.village("Soinaste", "")
    p.village("Räni", "")
    p.village("Laane", "")
    p.village("Külitse", "")
    p.village("Lemmatsi", "")
    p.village("Uhti", "")
    p.village("Õssu", "")
    p.village("Reola", "")
    p.village("Lepiku", "")
    p.village("Soosilla", "61710")
    p.village("Läti", "61706")
    p.village("Täsvere", "61711")

    p.municipality("Haaslava", "")
    p.smallborough("Roiu", "")
    p.village("Aardlapalu", "")
    p.village("Tõõraste", "")
    p.village("Aardla", "")
    p.village("Mõra", "")
    p.village("Lange", "")
    p.village("Aadami", "")
    p.village("Ignase", "")
    p.village("Kõivuküla", "")
    p.village("Koke", "62111")
    p.village("Kurepalu", "")
    p.village("Igevere", "62108")
    p.village("Päkste", "62119")
    p.village("Alaküla", "62106")
    p.village("Kitseküla", "62110")
    p.village("Paluküla", "62118")
    p.village("Uniküla", "62121")
    p.village("Metsanurga", "62116")

    p.municipality("Rõngu", "")
    p.smallborough("Käärdi", "")
    p.village("Teedla", "")
    p.village("Kalme", "")
    p.village("Raigaste", "")
    p.village("Valguta", "")
    p.village("Uderna", "")
    p.village("Lapetukme", "")
    p.village("Rannaküla", "61012")
    p.village("Kirepi", "61003")
    p.village("Lossimäe", "61009")
    p.village("Tammiste", "61013")
    p.village("Koruste", "61004")
    p.village("Piigandi", "61010")
    p.village("Käo", "61006")
    p.village("Tilga", "61015")
    p.village("Kõduküla", "61005")

    p.municipality("Kambja", "")
    p.village("Sulu", "")
    p.village("Pangodi", "")
    p.village("Visnapuu", "")
    p.village("Virulase", "")
    p.village("Vana-Kuuste", "")
    p.village("Madise", "")
    p.village("Kullaga", "62009")
    p.village("Kodijärve", "62008")
    p.village("Sirvaku", "62025")
    p.village("Kõrkküla", "62010")
    p.village("Mäeküla", "62013")
    p.village("Pühi", "62019")
    p.village("Raanitsa", "62020")
    p.village("Aakaru", "")
    p.village("Oomiste", "")
    p.village("Sipe", "62024")
    p.village("Kavandu", "62032")
    p.village("Reolasoo", "62022")
    p.village("Ivaste", "62005")
    p.village("Paali", "62015")
    p.village("Tatra", "62029")
    p.village("Pulli", "62018")
    p.village("Talvikese", "62028")
    p.village("Riiviku", "62023")
    p.village("Kammeri", "62007")
    p.village("Palumäe", "62016")
    p.village("Rebase", "62021")
    p.village("Lalli", "62011")
    p.village("Suure-Kambja", "62027")
    p.village("Kaatsi", "62006")

    p.town("Elva", "")
    p.municipality("Nõo", "")
    p.smallborough("Tõravere", "")
    p.village("Luke", "")
    p.village("Meeri", "")
    p.village("Tamsa", "")
    p.village("Nõgiaru", "")
    p.village("Etsaste", "")
    p.village("Vissi", "")
    p.village("Uuta", "61620")
    p.village("Ketneri", "61610")
    p.village("Altmäe", "61604")
    p.village("Kääni", "61612")
    p.village("Voika", "")
    p.village("Aiamaa", "61603")
    p.village("Laguja", "61613")
    p.village("Kolga", "61611")
    p.village("Enno", "61605")
    p.village("Sassi", "61617")
    p.village("Keeri", "61609")
    p.village("Unipiha", "61619")
    p.village("Järiste", "61608")

    p.town("Kallaste", "")
    p.municipality("Puhja", "")
    p.smallborough("Ulila", "")
    p.village("Võsivere", "")
    p.village("Tännassilma", "")
    p.village("Teilma", "")
    p.village("Rämsi", "")
    p.village("Võllinge", "61318")
    p.village("Mõisanurme", "61307")
    p.village("Saare", "")
    p.village("Järvaküla", "61304")
    p.village("Mäeselja", "61308")
    p.village("Poriküla", "61311")
    p.village("Vihavu", "61317")
    p.village("Ridaküla", "61312")
    p.village("Kaimi", "61305")
    p.village("Nasja", "61309")
    p.village("Palupõhja", "60547")
    p.village("Härjanurme", "61303")

    p.municipality("Alatskivi", "")
    p.village("Savimetsa", "60226")
    p.village("Linaleo", "60210")
    p.village("Sudemäe", "60227")
    p.village("Virtsu", "60231")
    p.village("Rupsi", "60223")
    p.village("Savastvere", "60225")
    p.village("Tõruvere", "60230")
    p.village("Orgemäe", "60213")
    p.village("Lahe", "60208")
    p.village("Rootsiküla", "60222")
    p.village("Nina", "60212")
    p.village("Pusi", "60217")
    p.village("Kõdesi", "60207")
    p.village("Ronisoo", "60221")
    p.village("Lahepera", "60209")
    p.village("Toruküla", "60229")
    p.village("Päiksi", "60218")
    p.village("Passi", "60215")
    p.village("Padakõrve", "60214")
    p.village("Kesklahe", "60204")
    p.village("Naelavere", "60211")
    p.village("Kokora", "60205")
    p.village("Alasoo", "60202")
    p.village("Pärsikivi", "60219")
    p.village("Peatskivi", "60216")
    p.village("Torila", "60228")
    p.village("Haapsipea", "60203")
    p.village("Saburi", "60224")
    p.village("Väljaküla", "60232")
    p.village("Riidma", "60220")
    p.village("Kuningvere", "60206")

    p.municipality("Mäksa", "")
    p.village("Melliste", "")
    p.village("Sudaste", "62310")
    p.village("Võõpste", "62316")
    p.village("Tigase", "62312")
    p.village("Kastre", "62305")
    p.village("Tammevaldma", "62311")
    p.village("Veskimäe", "62314")
    p.village("Sarakuste", "62309")
    p.village("Aruaia", "62303")
    p.village("Mäletjärve", "62307")
    p.village("Vana-Kastre", "62313")
    p.village("Kaagvere", "62317")
    p.village("Kaarlimõisa", "62304")
    p.village("Poka", "62308")
    p.village("Võruküla", "62315")

    p.municipality("Tähtvere", "")
    p.smallborough("Märja", "")
    p.village("Pihva", "")
    p.village("Kandiküla", "")
    p.village("Rahinge", "")
    p.village("Tüki", "")
    p.village("Ilmatsalu", "")
    p.village("Rõhu", "")
    p.village("Vorbuse", "")
    p.village("Haage", "")
    p.village("Kardla", "")

    p.municipality("Konguta", "")
    p.village("Annikoru", "")
    p.village("Metsalaane", "")
    p.village("Pööritsa", "61214")
    p.village("Kurelaane", "61206")
    p.village("Külaaseme", "61207")
    p.village("Poole", "61213")
    p.village("Mäeotsa", "61211")
    p.village("Kapsta", "61203")
    p.village("Vahessaare", "61215")
    p.village("Lembevere", "61208")
    p.village("Mälgi", "61212")
    p.village("Karijärve", "61204")
    p.village("Majala", "61209")
    p.village("Vellavere", "61216")
    p.village("Kobilu", "61205")

    p.municipality("Rannu", "")
    p.village("Tamme", "")
    p.village("Koopsi", "61106")
    p.smallborough("Kureküla", "")
    p.village("Utukolga", "61115")
    p.village("Järveküla", "61103")
    p.village("Sangla", "61112")
    p.village("Noorma", "61110")
    p.village("Vallapalu", "61116")
    p.village("Kaarlijärve", "61104")
    p.village("Kulli", "61107")
    p.village("Suure-Rakke", "61113")
    p.village("Ervu", "61102")
    p.village("Väike-Rakke", "61119")
    p.village("Paju", "61111")
    p.village("Verevi", "61118")
    p.village("Kipastu", "61105")

    p.municipality("Laeva", "")
    p.village("Kärevere", "")
    p.village("Siniküla", "")
    p.village("Valmaotsa", "60605")
    p.village("Kämara", "60602")
    p.village("Väänikvere", "60606")

    p.municipality("Võnnu", "")
    p.village("Hammaste", "62404")
    p.village("Imste", "62405")
    p.village("Kannu", "62407")
    p.village("Agali", "62402")
    p.village("Ahunapalu", "62414")
    p.village("Terikeste", "62413")
    p.village("Kurista", "62408")
    p.village("Rookse", "62412")
    p.village("Lääniste", "62411")
    p.village("Issaku", "62406")
    p.village("Kõnnu", "62409")
    p.village("Liispõllu", "62410")

    p.municipality("Peipsiääre", "")
    p.smallborough("Varnja", "")
    p.smallborough("Kolkja", "")
    p.village("Savka", "60303")
    p.smallborough("Kasepää", "60302")
    p.village("Sipelga", "60304")

    p.municipality("Meeksi", "")
    p.smallborough("Mehikoorma", "")
    p.village("Haavametsa", "62504")
    p.village("Rõka", "62509")
    p.village("Järvselja", "62506")
    p.village("Aravu", "62503")
    p.village("Sikakurmu", "62510")
    p.village("Meerapalu", "62502")
    p.village("Jõepera", "62505")
    p.village("Parapalu", "62508")

    p.municipality("Vara", "")
    p.village("Keressaare", "")
    p.village("Koosa", "")
    p.village("Põrgu", "60418")
    p.village("Rehemetsa", "60419")
    p.village("Kusma", "60408")
    p.village("Põdra", "60416")
    p.village("Sookalduse", "60421")
    p.village("Matjama", "60431")
    p.village("Koosalaane", "60407")
    p.village("Vanaussaia", "60425")
    p.village("Praaga", "60415")
    p.village("Selgise", "60420")
    p.village("Pilpaküla", "60414")
    p.village("Tähemaa", "60423")
    p.village("Meoma", "60410")
    p.village("Särgla", "60422")
    p.village("Mustametsa", "60412")
    p.village("Undi", "60424")
    p.village("Metsakivi", "60411")
    p.village("Kuusiku", "60409")
    p.village("Kargaja", "60404")
    p.village("Alajõe", "60403")
    p.village("Kauda", "60405")
    p.village("Põldmaa", "60417")
    p.village("Välgi", "60427")
    p.village("Ätte", "60428")
    p.village("Papiaru", "60413")

    p.municipality("Piirissaare", "")
    p.village("Piiri", "")
    p.village("Tooni", "62603")

    p.municipality("Vehendi", "")
    p.municipality("Kriimani", "")
    p.municipality("Illi", "")
    p.municipality("Neemisküla", "")

