# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Pärnu (county)
    p.county("Pärnu", "")
    p.municipality("Halinga", "")
    p.village("Libatse", "")
    p.borough("Pärnu-Jaagupi", "")
    p.village("Tõrdu", "")
    p.village("Pitsalu", "87230")
    p.village("Rukkiküla", "87233")
    p.village("Kodesmaa", "87217")
    p.village("Salu", "87234")
    p.village("Mäeküla", "87225")
    p.village("Helenurme", "87213")
    p.village("Altküla", "87204")
    p.village("Anelema", "87205")
    p.village("Kuninga", "87218")
    p.village("Arase", "87206")
    p.village("Tarva", "")
    p.village("Kablima", "87214")
    p.village("Oese", "87227")
    p.village("Valistre", "87242")
    p.village("Vakalepa", "87241")
    p.village("Sepaküla", "87235")
    p.village("Enge", "87210")
    p.village("Vahenurme", "87101")
    p.village("Pereküla", "87229")
    p.village("Sõõrike", "87237")
    p.village("Vee", "87243")
    p.village("Ertsma", "87211")
    p.village("Maima", "87223")
    p.village("Mõisaküla", "87224")
    p.village("Kaelase", "87215")
    p.village("Roodi", "87232")
    p.village("Pallika", "87228")
    p.village("Loomse", "87222")
    p.village("Lehtmetsa", "87220")
    p.village("Langerma", "87219")
    p.village("Lehu", "87221")
    p.village("Kangru", "87216")
    p.village("Tühjasma", "87240")
    p.village("Eense", "87208")
    p.village("Soosalu", "87236")
    p.village("Aasa", "87203")
    p.village("Eerma", "87209")
    p.village("Pööravere", "87231")
    p.village("Naartse", "87226")

    p.municipality("Tootsi", "")
    p.municipality("Vändra", "")
    p.village("Vihtra", "")
    p.village("Võidula", "")
    p.village("Kergu", "")
    p.village("Suurejõe", "")
    p.village("Kaisma", "")
    p.village("Viluvere", "87633")
    p.village("Rahnoja", "87622")
    p.village("Luuri", "87614")
    p.village("Kullimaa", "87611")
    p.village("Ünnaste", "87636")
    p.village("Kobra", "87609")
    p.village("Massu", "87616")
    p.village("Rõusa", "87624")
    p.village("Allikõnnu", "87604")
    p.village("Oriküla", "87619")
    p.village("Kalmaru", "87607")
    p.village("Kirikumõisa", "87608")
    p.village("Kurgja", "87612")
    p.village("Metsavere", "87405")
    p.village("Veskisoo", "87632")
    p.village("Leetva", "87613")
    p.village("Tagassaare", "87629")
    p.village("Lüüste", "87615")
    p.village("Rätsepa", "")
    p.village("Aluste", "87601")
    p.village("Rae", "87621")
    p.village("Kose", "87610")
    p.village("Pärnjõe", "87620")
    p.village("Reinumurru", "87623")
    p.village("Rahkama", "87406")
    p.village("Sikana", "87627")
    p.village("Kaansoo", "87605")
    p.village("Võiera", "87635")
    p.village("Kõnnu", "87403")
    p.village("Venekuusiku", "87631")
    p.village("Sohlu", "87407")
    p.village("Säästla", "87628")
    p.village("Samliku", "87626")
    p.village("Kadjaste", "87606")
    p.village("Vaki", "87630")
    p.village("Mustaru", "87617")
    p.village("Mädara", "87618")

    p.municipality("Tori", "")
    p.village("Jõesuu", "")
    p.village("Piistaoja", "")
    p.village("Kõrsa", "")
    p.village("Selja", "")
    p.village("Taali", "")
    p.village("Urumarja", "")
    p.village("Kildemaa", "86805")
    p.village("Oore", "86812")
    p.village("Elbi", "86804")
    p.village("Aesoo", "86803")
    p.village("Muti", "86811")
    p.village("Riisa", "86815")
    p.village("Levi", "86808")
    p.village("Kuiaru", "86806")
    p.village("Muraka", "86810")
    p.village("Tohera", "86819")
    p.village("Mannare", "86809")
    p.village("Randivälja", "86814")
    p.village("Võlli", "86821")

    p.municipality("Tõstamaa", "")
    p.village("Kiraste", "88108")
    p.village("Lao", "88110")
    p.village("Pootsi", "88115")
    p.village("Tõlli", "88119")
    p.village("Rammuka", "88117")
    p.village("Ranniku", "88118")
    p.village("Lõuka", "88111")
    p.village("Tõhela", "88102")
    p.village("Seliste", "88103")
    p.village("Peerni", "88114")
    p.village("Kastna", "88106")
    p.village("Alu", "88104")
    p.village("Ermistu", "88105")
    p.village("Kavaru", "88107")
    p.village("Värati", "88120")
    p.village("Männikuste", "88113")
    p.village("Päraküla", "88116")
    p.village("Manija", "88112")
    p.village("Kõpu", "88109")

    p.municipality("Tahkuranna", "")
    p.village("Reiu", "")
    p.village("Uulu", "")
    p.smallborough("Võiste", "")
    p.village("Lepaküla", "")
    p.village("Laadi", "")
    p.village("Piirumi", "86507")
    p.village("Metsaküla", "")
    p.village("Leina", "86504")

    p.municipality("Sauga", "")
    p.village("Tammiste", "")
    p.village("Kilksama", "")
    p.village("Eametsa", "")
    p.village("Nurme", "")
    p.village("Urge", "")
    p.village("Vainu", "")
    p.village("Räägu", "85006")
    p.village("Kiisa", "85002")
    p.village("Rütavere", "85007")
    p.village("Pulli", "85005")

    p.municipality("Paikuse", "")
    p.village("Silla", "")
    p.village("Seljametsa", "")
    p.village("Tammuru", "")
    p.village("Põlendmaa", "86603")
    p.village("Vaskrääma", "86606")

    p.town("Pärnu", "")
    p.town("Sindi", "")
    p.municipality("Audru", "")
    p.village("Kõima", "")
    p.village("Papsaare", "")
    p.village("Lemmetsa", "")
    p.village("Liiva", "")
    p.village("Malda", "")
    p.village("Marksa", "")
    p.village("Kihlepa", "")
    p.village("Lindi", "")
    p.village("Jõõpre", "")
    p.village("Kabriste", "")
    p.village("Põldeotsa", "")
    p.village("Saulepa", "")
    p.village("Valgeranna", "")
    p.village("Ahaste", "")
    p.village("Oara", "88316")
    p.village("Soeva", "88323")
    p.village("Tuuraste", "88325")
    p.village("Saari", "88321")
    p.village("Soomra", "")
    p.village("Kärbu", "88310")
    p.village("Põhara", "88318")
    p.village("Liu", "88313")
    p.village("Eassalu", "88307")
    p.village("Ridalepa", "88320")

    p.municipality("Häädemeeste", "")
    p.village("Kabli", "")
    p.village("Rannametsa", "86016")
    p.village("Papisilla", "86013")
    p.village("Penu", "86014")
    p.village("Metsapoole", "86010")
    p.village("Orajõe", "86012")
    p.village("Urissaare", "86019")
    p.village("Arumetsa", "86006")
    p.village("Sooküla", "86017")
    p.village("Massiaru", "86004")
    p.village("Majaka", "")
    p.village("Soometsa", "86018")
    p.village("Krundiküla", "86008")
    p.village("Võidu", "86021")
    p.village("Uuemaa", "86020")
    p.village("Pulgoja", "86015")
    p.village("Jaagupi", "86007")
    p.village("Ikla", "86005")
    p.village("Nepste", "86011")
    p.village("Treimani", "86003")

    p.town("Kilingi-Nõmme", "")
    p.municipality("Are", "")
    p.village("Kurena", "")
    p.village("Parisselja", "87308")
    p.village("Suigu", "87302")
    p.village("Elbu", "87304")
    p.village("Niidu", "87307")
    p.village("Pärivere", "87309")
    p.village("Tabria", "87311")
    p.village("Lepplaane", "87306")
    p.village("Murru", "87310")
    p.village("Eavere", "87303")
    p.village("Võlla", "87312")

    p.municipality("Lavassaare", "")
    p.municipality("Varbla", "")
    p.village("Käru", "88217")
    p.village("Kidise", "88212")
    p.village("Saare", "88231")
    p.village("Paatsalu", "88204")
    p.village("Sookalda", "88233")
    p.village("Maade", "88218")
    p.village("Kilgi", "88213")
    p.village("Tiilima", "88235")
    p.village("Matsi", "88219")
    p.village("Koeri", "88214")
    p.village("Ännikse", "88240")
    p.village("Korju", "88215")
    p.village("Õhu", "88239")
    p.village("Tõusi", "88236")
    p.village("Piha", "88225")
    p.village("Täpsi", "88237")
    p.village("Mõtsu", "88222")
    p.village("Raheste", "88227")
    p.village("Paadrema", "88202")
    p.village("Kulli", "88216")
    p.village("Mereäärse", "88220")
    p.village("Raespa", "88226")
    p.village("Aruküla", "88206")
    p.village("Helmküla", "88208")
    p.village("Hõbesalu", "88209")
    p.village("Rauksi", "88229")
    p.village("Muriste", "88221")
    p.village("Mäliküla", "88223")
    p.village("Kanamardi", "88211")
    p.village("Saulepi", "88203")
    p.village("Tamba", "88234")
    p.village("Vaiste", "88238")
    p.village("Haapsi", "88207")
    p.village("Rädi", "88230")
    p.village("Allika", "88205")
    p.village("Rannaküla", "88228")
    p.village("Kadaka", "88210")
    p.village("Nõmme", "88224")

    p.municipality("Saarde", "")
    p.smallborough("Tihemetsa", "")
    p.village("Veelikse", "")
    p.village("Tõlla", "")
    p.village("Tali", "")
    p.village("Tuuliku", "86108")
    p.village("Sigaste", "86214")
    p.village("Reinu", "86107")
    p.village("Leipste", "86209")
    p.village("Kalita", "86206")
    p.village("Marina", "86105")
    p.village("Jäärja", "86205")
    p.village("Laiksaare", "86103")
    p.village("Väljaküla", "86215")
    p.village("Mustla", "86212")
    p.village("Viisireiu", "86109")
    p.village("Pihke", "86106")
    p.village("Kamali", "86207")
    p.village("Lodja", "86210")
    p.village("Lanksaare", "86104")
    p.village("Marana", "86211")
    p.village("Kanaküla", "86204")
    p.village("Kärsu", "86208")
    p.village("Oissaare", "86216")

    p.municipality("Surju", "")
    p.village("Kalda", "")
    p.village("Ristiküla", "86410")
    p.village("Jaamaküla", "86403")
    p.village("Lähkma", "86407")
    p.village("Kikepera", "86405")
    p.village("Rabaküla", "86409")
    p.village("Kõveri", "86406")
    p.village("Saunametsa", "86411")
    p.village("Ilvese", "86402")

    p.municipality("Kihnu", "")
    p.village("Linaküla", "")
    p.village("Lemsi", "88002")
    p.village("Sääre", "88005")
    p.village("Rootsiküla", "88004")

    p.municipality("Koonga", "")
    p.village("Võrungi", "88441")
    p.village("Tamme", "88434")
    p.village("Ura", "88436")
    p.village("Paimvere", "88425")
    p.village("Irta", "88407")
    p.village("Pikavere", "88430")
    p.village("Peantse", "88428")
    p.village("Kibura", "88415")
    p.village("Vastaba", "88438")
    p.village("Iska", "88408")
    p.village("Kurese", "88418")
    p.village("Nätsi", "88424")
    p.village("Sookatse", "88433")
    p.village("Jänistvere", "88410")
    p.village("Järve", "88411")
    p.village("Tõitse", "88435")
    p.village("Joonuse", "88409")
    p.village("Urita", "88437")
    p.village("Õepa", "88442")
    p.village("Karuba", "88414")
    p.village("Võitra", "88440")
    p.village("Kuhu", "88417")
    p.village("Emmu", "88405")
    p.village("Kiisamaa", "88416")
    p.village("Rabavere", "88431")
    p.village("Palatu", "88426")
    p.village("Nedrema", "88423")
    p.village("Oidrema", "88404")
    p.village("Naissoo", "88422")
    p.village("Kalli", "88412")
    p.village("Veltsa", "88439")
    p.village("Hõbeda", "88406")
    p.village("Salevere", "88432")
    p.village("Mihkli", "88421")
    p.village("Maikse", "88420")
    p.village("Piisu", "88429")
    p.village("Karinõmme", "88413")
    p.village("Parasmaa", "88427")
    p.village("Lõpe", "88402")

    p.municipality("Metsaääre", "")
    p.municipality("Aruvälja", "")

