# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    
    # Järva (county)
    p.county("Järva", "")
    p.municipality("Türi", "")
    p.smallborough("Särevere", "")
    p.smallborough("Oisu", "")
    p.village("Lokuta", "")
    p.village("Jändja", "")
    p.village("Kabala", "")
    p.village("Türi-Alliku", "")
    p.village("Poaka", "")
    p.village("Karjaküla", "72242")
    p.village("Rikassaare", "72307")
    p.village("Väljaotsa", "72311")
    p.village("Villevere", "72006")
    p.village("Kirna", "72231")
    p.village("Rassi", "72007")
    p.village("Raukla", "72305")
    p.village("Laupa", "72102")
    p.village("Saareotsa", "72308")
    p.village("Tännassilma", "72310")
    p.village("Pibari", "72005")
    p.village("Pala", "72234")
    p.village("Kurla", "72009")
    p.village("Ollepa", "72002")
    p.village("Äiamaa", "72312")
    p.village("Vilita", "72245")
    p.village("Retla", "72306")
    p.village("Sagevere", "72003")
    p.village("Arkma", "72011")
    p.village("Änari", "72241")
    p.village("Metsaküla", "72303")
    p.village("Põikva", "72244")
    p.village("Kärevere", "72302")
    p.village("Tori", "72230")
    p.village("Taikse", "72309")
    p.village("Meossaare", "72010")
    p.village("Näsuvere", "72246")

    p.municipality("Roosna-Alliku", "")
    p.village("Viisu", "")
    p.village("Valasti", "73210")
    p.village("Kihme", "73206")
    p.village("Koordi", "73212")
    p.village("Oeti", "73208")
    p.village("Kodasema", "73207")
    p.village("Kirisaare", "73211")
    p.village("Kaaruka", "73205")
    p.village("Tännapere", "73209")
    p.village("Allikjärve", "73203")
    p.village("Vedruka", "73213")

    p.town("Paide", "")
    p.village("Tarbja", "")
    p.village("Kriilevälja", "")
    p.village("Sargvere", "")
    p.village("Sillaotsa", "")
    p.village("Sõmeru", "72614")
    p.village("Viraksaare", "")
    p.village("Veskiaru", "72760")
    p.village("Mustla", "72607")
    p.village("Ojaküla", "72610")
    p.village("Mustla-Nõmme", "72608")
    p.village("Eivere", "72757")
    p.village("Mäeküla", "")
    p.village("Korba", "72753")
    p.village("Valgma", "72606")
    p.village("Võõbu", "72615")
    p.village("Kirila", "72755")
    p.village("Mündi", "72762")
    p.village("Seinapalu", "72761")
    p.village("Otiku", "72611")
    p.village("Nurme", "72609")
    p.village("Prääma", "72763")
    p.village("Nurmsi", "72603")
    p.village("Purdi", "72613")
    p.village("Mäo", "72751")
    p.village("Suurpalu", "72605")
    p.village("Anna", "72601")
    p.village("Pikaküla", "72756")

    p.municipality("Väätsa", "")
    p.village("Aasuvälja", "")
    p.village("Reopalu", "")
    p.village("Ülejõe", "")
    p.village("Lõõla", "72814")
    p.village("Roovere", "72805")
    p.village("Vissuvere", "72812")
    p.village("Väljataguse", "72802")
    p.village("Saueaugu", "72813")
    p.village("Röa", "72806")
    p.village("Piiumetsa", "72804")

    p.municipality("Ambla", "")
    p.smallborough("Aravete", "")
    p.smallborough("Käravete", "")
    p.village("Raka", "")
    p.village("Kurisoo", "")
    p.village("Jõgisoo", "")
    p.village("Roosna", "")
    p.village("Märjandi", "73513")
    p.village("Sääsküla", "73511")
    p.village("Kukevere", "73512")
    p.village("Mägise", "73510")
    p.village("Reinevere", "73507")
    p.village("Rava", "73506")

    p.municipality("Järva-Jaani", "")
    p.village("Karinu", "")
    p.village("Metsla", "73307")
    p.village("Kuksema", "73306")
    p.village("Jalalõpe", "73303")
    p.village("Jalgsema", "73304")
    p.village("Kagavere", "73305")
    p.village("Seliküla", "73310")
    p.village("Metstaguse", "73308")
    p.village("Ramma", "73309")

    p.municipality("Koeru", "")
    p.village("Ervita", "")
    p.village("Vao", "")
    p.village("Rõhu", "73018")
    p.village("Udeva", "73019")
    p.village("Tammiku", "73023")
    p.village("Preedi", "73017")
    p.village("Norra", "73016")
    p.village("Kuusna", "73008")
    p.village("Visusti", "73012")
    p.village("Valila", "73024")
    p.village("Tudre", "73010")
    p.village("Väinjärve", "73021")
    p.village("Santovi", "73005")
    p.village("Koidu-Ellavere", "73027")
    p.village("Vahuküla", "73020")
    p.village("Aruküla", "73004")
    p.village("Jõeküla", "73014")
    p.village("Kalitsa", "73022")
    p.village("Liusvere", "73015")
    p.village("Kapu", "73007")
    p.village("Puhmu", "73006")
    p.village("Laaneotsa", "73013")
    p.village("Salutaguse", "73009")
    p.village("Vuti", "73011")
    p.village("Merja", "73026")
    p.village("Abaja", "73025")

    p.municipality("Kareda", "")
    p.village("Esna", "")
    p.smallborough("Peetri", "")
    p.village("Õle", "73108")
    p.village("Köisi", "73104")
    p.village("Ataste", "73103")
    p.village("Müüsleri", "73105")
    p.village("Vodja", "73111")
    p.village("Küti", "73106")
    p.village("Ämbra", "73110")
    p.village("Ammuta", "73107")
    p.village("Öötla", "73112")

    p.municipality("Albu", "")
    p.village("Pullevere", "")
    p.village("Järva-Madise", "")
    p.village("Ahula", "")
    p.village("Seidla", "73407")
    p.village("Vetepere", "73416")
    p.village("Ageri", "73408")
    p.village("Soosalu", "73414")
    p.village("Mägede", "73412")
    p.village("Orgmetsa", "73405")
    p.village("Sugalepa", "73415")
    p.village("Kaalepi", "73403")
    p.village("Lehtmetsa", "73410")
    p.village("Mõnuvere", "73411")
    p.village("Neitla", "73404")
    p.village("Peedu", "73413")

    p.municipality("Imavere", "")
    p.village("Käsukonna", "")
    p.village("Taadikvere", "")
    p.village("Jalametsa", "72403")
    p.village("Võrevere", "72409")
    p.village("Eistvere", "72402")
    p.village("Laimetsa", "72410")
    p.village("Kiigevere", "72405")
    p.village("Pällastvere", "72412")
    p.village("Puiatu", "")
    p.village("Järavere", "72404")
    p.village("Tammeküla", "72411")

    p.municipality("Koigi", "")
    p.village("Päinurme", "")
    p.village("Huuksi", "72503")
    p.village("Vaali", "72513")
    p.village("Tamsi", "72509")
    p.village("Lähevere", "72511")
    p.village("Silmsi", "72507")
    p.village("Sõrandu", "72508")
    p.village("Keri", "72505")
    p.village("Väike-Kareda", "72510")
    p.village("Prandi", "72506")
    p.village("Kahala", "")
    p.village("Rutikvere", "72512")

    p.municipality("Kolu", "")

