# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Põlva (county)
    p.county("Põlva", "")
    p.town("Räpina", "")
    p.village("Ristipalo", "")
    p.village("Ruusa", "")
    p.village("Leevaku", "")
    p.village("Linte", "")
    p.village("Naha", "64411")
    p.village("Kõnnu", "64407")
    p.village("Võiardi", "64426")
    p.village("Saareküla", "64419")
    p.village("Tsirksi", "64425")
    p.village("Sillapää", "64420")
    p.village("Köstrimäe", "64408")
    p.village("Toolamaa", "64423")
    p.village("Võuküla", "64427")
    p.village("Mägiotsa", "64410")
    p.village("Nulga", "64412")
    p.village("Pindi", "64413")
    p.village("Kassilaane", "64406")
    p.village("Raigla", "64417")
    p.village("Tooste", "64424")
    p.village("Meelva", "64409")
    p.village("Jaanikeste", "64405")
    p.village("Rahumäe", "64416")
    p.village("Pääsna", "64414")
    p.village("Sülgoja", "64422")
    p.village("Raadama", "64415")
    p.village("Suure-Veerksu", "64421")

    p.town("Põlva", "")
    p.village("Soesaare", "")
    p.village("Rosma", "")
    p.village("Himmaste", "")
    p.village("Taevaskoja", "")
    p.village("Mammaste", "")
    p.village("Tromsi", "63223")
    p.village("Adiste", "63204")
    p.village("Valgesoo", "63226")
    p.village("Vanaküla", "63227")
    p.village("Metste", "63213")
    p.village("Nooritsmetsa", "63215")
    p.village("Peri", "63218")
    p.village("Holvandi", "63207")
    p.village("Puskaru", "63219")
    p.village("Meemaste", "63212")
    p.village("Eoste", "63206")
    p.village("Puuri", "63220")
    p.village("Kähri", "63209")
    p.village("Orajõe", "63216")
    p.village("Aarna", "63203")
    p.village("Lutsu", "63210")
    p.village("Tännassilma", "63224")
    p.village("Kiuma", "")
    p.village("Uibujärve", "63225")
    p.village("Miiaste", "63214")
    p.village("Partsi", "63217")
    p.village("Andre", "63205")

    p.municipality("Veriora", "")
    p.village("Leevi", "")
    p.village("Männisalu", "64215")
    p.village("Viira", "64224")
    p.village("Kullamäe", "64210")
    p.village("Haavapää", "64203")
    p.village("Nohipalo", "64216")
    p.village("Koolmajärve", "64209")
    p.village("Kunksilla", "64211")
    p.village("Laho", "")
    p.village("Süvahavva", "64220")
    p.village("Soohara", "64219")
    p.village("Timo", "64221")
    p.village("Sarvemäe", "64218")
    p.village("Vareste", "64222")
    p.village("Kikka", "64206")
    p.village("Lihtensteini", "64213")
    p.village("Väike-Veerksu", "64228")
    p.village("Kirmsi", "64207")
    p.village("Vändra", "64229")
    p.village("Võika", "64227")
    p.village("Jõeveere", "64233")
    p.village("Himmiste", "64204")
    p.village("Viluste", "64225")
    p.village("Mõtsavaara", "64214")
    p.village("Koolma", "64208")
    p.village("Vinso", "64226")
    p.village("Pahtpää", "64217")
    p.village("Jõevaara", "64205")
    p.village("Verioramõisa", "64223")

    p.municipality("Kanepi", "")
    p.village("Põlgaste", "")
    p.village("Magari", "")
    p.village("Jõgehara", "63109")
    p.village("Peetrimõisa", "63118")
    p.village("Kooraste", "63114")
    p.village("Sõreste", "63121")
    p.village("Lauri", "63115")
    p.village("Soodoma", "63124")
    p.village("Jõksi", "63110")
    p.village("Heisri", "63106")
    p.village("Koigera", "63113")
    p.village("Hino", "63107")
    p.village("Rebaste", "63120")
    p.village("Kaagvere", "63103")
    p.village("Närapää", "63117")
    p.village("Erastvere", "63105")
    p.village("Piigandi", "63119")
    p.village("Kaagna", "63111")
    p.village("Hurmi", "63108")
    p.village("Varbuse", "63122")
    p.village("Karste", "63112")

    p.municipality("Ahja", "")
    p.village("Ibaste", "63703")
    p.village("Akste", "63702")
    p.village("Mõtsküla", "63708")
    p.village("Vanamõisa", "63709")
    p.village("Kosova", "63704")
    p.village("Mustakurmu", "63707")
    p.village("Loko", "63706")
    p.village("Kärsa", "63705")

    p.municipality("Kõlleste", "")
    p.village("Krootuse", "")
    p.village("Prangli", "")
    p.village("Veski", "63511")
    p.village("Häätaru", "63502")
    p.village("Tõdu", "63510")
    p.village("Karaski", "63504")
    p.village("Voorepalu", "63512")
    p.village("Piigaste", "63507")
    p.village("Palutaja", "63506")
    p.village("Tuulemäe", "63509")
    p.village("Ihamaru", "63503")

    p.municipality("Vastse-Kuuste", "")
    p.village("Vooreküla", "")
    p.village("Karilatsi", "")
    p.village("Valgemetsa", "63610")
    p.village("Kiidjärve", "63604")
    p.village("Koorvere", "63605")
    p.village("Logina", "63607")
    p.village("Padari", "63609")
    p.village("Lootvina", "63608")
    p.village("Leevijõe", "63606")

    p.municipality("Värska", "")
    p.village("Lobotka", "")
    p.village("Tonja", "64025")
    p.village("Popovitsa", "64019")
    p.village("Rääptsova", "64020")
    p.village("Velna", "64030")
    p.village("Õrsava", "64035")
    p.village("Väike-Rõsna", "64034")
    p.village("Podmotsa", "64018")
    p.village("Verhulitsa", "64031")
    p.village("Litvina", "64011")
    p.village("Korela", "64007")
    p.village("Vaartsi", "64028")
    p.village("Saatse", "64037")
    p.village("Matsuri", "64036")
    p.village("Vedernika", "64029")
    p.village("Ulitina", "64027")
    p.village("Perdaku", "64017")
    p.village("Kremessova", "64009")
    p.village("Saabolda", "64021")
    p.village("Sesniki", "64023")
    p.village("Koidula", "64004")
    p.village("Kolodavitsa", "64005")
    p.village("Kolossova", "64006")
    p.village("Lutepää", "64013")
    p.village("Pattina", "64016")
    p.village("Nedsaja", "64015")
    p.village("Säpina", "64024")
    p.village("Võpolsova", "64033")
    p.village("Kundruse", "64010")
    p.village("Voropi", "64032")
    p.village("Määsovitsa", "64014")
    p.village("Kostkova", "64008")
    p.village("Samarina", "64022")
    p.village("Treski", "64026")

    p.municipality("Mikitamäe", "")
    p.village("Võõpsu", "")
    p.village("Lüübnitsa", "")
    p.village("Beresje", "")
    p.village("Niitsiku", "64319")
    p.village("Puugnitsa", "64311")
    p.village("Rõsna", "64312")
    p.village("Igrise", "64304")
    p.village("Audjassaare", "64302")
    p.village("Järvepää", "64305")
    p.village("Usinitsa", "64316")
    p.village("Selise", "64314")
    p.village("Rääsolaane", "64313")
    p.village("Varesmäe", "64317")
    p.village("Laossina", "64308")
    p.village("Karisilla", "64307")
    p.village("Toomasmäe", "64315")

    p.municipality("Mooste", "")
    p.village("Terepi", "64613")
    p.village("Kastmekoja", "64608")
    p.village("Rasina", "64618")
    p.village("Jaanimõisa", "64604")
    p.village("Säässaare", "64612")
    p.village("Säkna", "64611")
    p.village("Kauksi", "64617")
    p.village("Viisli", "64614")
    p.village("Savimäe", "64609")
    p.village("Kanassaare", "64607")
    p.village("Kaaru", "64605")
    p.village("Kadaja", "64606")
    p.village("Suurmetsa", "64610")

    p.municipality("Orava", "")
    p.village("Piusa", "")
    p.village("Suuremetsa", "64105")
    p.village("Kliima", "64110")
    p.village("Tamme", "64106")
    p.village("Hanikase", "64107")
    p.village("Luuska", "64117")
    p.village("Praakmani", "64104")
    p.village("Kakusuu", "64109")
    p.village("Madi", "64118")
    p.village("Kõvera", "64115")
    p.village("Liinamäe", "64116")
    p.village("Korgõmõisa", "64112")
    p.village("Vivva", "64131")
    p.village("Päka", "64123")
    p.village("Jantra", "64103")
    p.village("Tuderna", "64130")
    p.village("Kahkva", "")
    p.village("Rõssa", "64127")
    p.village("Kamnitsa", "64111")
    p.village("Riihora", "64126")
    p.village("Lepassaare", "64102")
    p.village("Oro", "64121")
    p.village("Pääväkese", "64124")
    p.village("Marga", "64119")
    p.village("Kõivsaare", "64113")
    p.village("Soe", "64128")
    p.village("Soena", "64129")
    p.village("Rebasmäe", "64125")
    p.village("Kõliküla", "64114")

    p.municipality("Valgjärve", "")
    p.village("Saverna", "")
    p.village("Sirvaste", "63413")
    p.village("Abissaare", "63404")
    p.village("Hauka", "63406")
    p.village("Krüüdneri", "63408")
    p.village("Sulaoja", "63414")
    p.village("Maaritsa", "63417")
    p.village("Vissi", "63416")
    p.village("Aiaste", "63405")
    p.village("Puugi", "63412")
    p.village("Tiido", "63415")
    p.village("Pikajärve", "63410")
    p.village("Mügra", "63409")
    p.village("Kooli", "63407")
    p.village("Pikareinu", "63411")

    p.municipality("Laheda", "")
    p.village("Tilsi", "")
    p.village("Himma", "63002")
    p.village("Pragi", "63007")
    p.village("Lahe", "63004")
    p.village("Vardja", "63011")
    p.village("Mustajõe", "63005")
    p.village("Vana-Koiola", "63010")
    p.village("Roosi", "63008")
    p.village("Naruski", "63006")
    p.village("Joosu", "63003")
    p.village("Suurküla", "63009")


