# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    
    # Jõgeva (county)
    p.county("Jõgeva", "")
    p.municipality("Torma", "")
    p.smallborough("Sadala", "")
    p.village("Ookatku", "48512")
    p.village("Rääbise", "48516")
    p.village("Kodismaa", "48505")
    p.village("Sätsuvere", "48517")
    p.village("Võtikvere", "48525")
    p.village("Kantküla", "48526")
    p.village("Rassiku", "48514")
    p.village("Leedi", "48508")
    p.village("Tuimõisa", "48519")
    p.village("Tähkvere", "48521")
    p.village("Võidivere", "48524")
    p.village("Vaiatu", "48522")
    p.village("Iravere", "48503")
    p.village("Kõnnu", "48507")
    p.village("Tealama", "48518")
    p.village("Tõikvere", "48520")
    p.village("Vanamõisa", "48523")
    p.village("Näduvere", "48511")
    p.village("Reastvere", "48515")
    p.village("Oti", "48513")
    p.village("Liikatku", "48509")
    p.village("Lilastvere", "48510")
    p.village("Koimula", "48506")

    p.town("Põltsamaa", "")
    p.smallborough("Adavere", "")
    p.village("Esku", "")
    p.village("Kuningamäe", "")
    p.village("Mõhküla", "")
    p.village("Lustivere", "")
    p.village("Kaavere", "48006")
    p.village("Tõrenurme", "48025")
    p.village("Väike-Kamari", "48030")
    p.village("Pilu", "48018")
    p.village("Annikvere", "48004")
    p.village("Kablaküla", "48007")
    p.village("Lebavere", "48012")
    p.village("Võhmanõmme", "48028")
    p.village("Vitsjärve", "48027")
    p.village("Rõstla", "48022")
    p.village("Kaliküla", "48008")
    p.village("Kalme", "48031")
    p.village("Umbusi", "48026")
    p.village("Neanurme", "48015")
    p.village("Mällikvere", "48014")
    p.village("Pauastvere", "48017")
    p.village("Pudivere", "48019")
    p.village("Puduküla", "48020")
    p.village("Nõmavere", "48016")
    p.village("Sulustvere", "48024")
    p.village("Puiatu", "48021")
    p.village("Võisiku", "48029")
    p.smallborough("Kamari", "48003")
    p.village("Alastvere", "48010")
    p.village("Räsna", "48023")

    p.municipality("Tabivere", "")
    p.village("Voldi", "")
    p.village("Kõduküla", "")
    p.village("Lilu", "49113")
    p.village("Sortsi", "49119")
    p.village("Kaitsemõisa", "49106")
    p.village("Kõnnujõe", "49110")
    p.village("Elistvere", "49103")
    p.village("Reinu", "49117")
    p.village("Valgma", "49123")
    p.village("Tormi", "49120")
    p.village("Õvanurme", "49125")
    p.village("Pataste", "49115")
    p.village("Otslava", "49114")
    p.village("Maarja-Magdaleena", "49126")
    p.village("Vahi", "49122")
    p.village("Kassema", "49107")
    p.village("Juula", "49104")
    p.village("Kärksi", "49112")
    p.village("Uhmardu", "49121")
    p.village("Sepa", "49118")
    p.village("Koogi", "49108")
    p.village("Kaiavere", "")
    p.village("Raigastvere", "49116")
    p.village("Kõrenduse", "49111")

    p.town("Mustvee", "")
    p.town("Jõgeva", "")
    p.smallborough("Kuremaa", "")
    p.village("Õuna", "")
    p.village("Mooritsa", "")
    p.smallborough("Laiuse", "")
    p.smallborough("Siimusti", "")
    p.village("Vana-Jõgeva", "")
    p.village("Lemuvere", "48417")
    p.village("Liivoja", "48418")
    p.village("Alavere", "48405")
    p.village("Kõola", "48414")
    p.village("Rohe", "48428")
    p.village("Viruvere", "48435")
    p.village("Painküla", "48422")
    p.village("Lõpe", "48440")
    p.village("Kaude", "48411")
    p.village("Ellakvere", "48406")
    p.village("Selli", "48429")
    p.village("Endla", "48407")
    p.village("Kaera", "48409")
    p.village("Raaduvere", "48427")
    p.village("Pedja", "48426")
    p.village("Vilina", "48434")
    p.village("Väljaotsa", "48441")
    p.village("Pakaste", "48423")
    p.village("Kurista", "48413")
    p.village("Paduvere", "48421")
    p.village("Patjala", "48425")
    p.village("Laiusevälja", "48416")
    p.village("Soomevere", "48430")
    p.village("Võduvere", "48436")
    p.village("Vaimastvere", "48446")
    p.village("Võikvere", "48437")
    p.village("Palupere", "48424")
    p.village("Kivijärve", "48412")
    p.village("Teilma", "48431")
    p.village("Tooma", "48432")
    p.village("Kassinurme", "48410")
    p.village("Kärde", "48415")
    p.village("Mõisamaa", "48420")

    p.municipality("Palamuse", "")
    p.village("Ehavere", "49205")
    p.village("Süvalepa", "49219")
    p.village("Eerikvere", "49204")
    p.village("Imukvere", "49206")
    p.village("Sudiste", "49218")
    p.village("Pikkjärve", "49213")
    p.village("Kudina", "49210")
    p.village("Järvepera", "49207")
    p.village("Visusti", "49224")
    p.village("Mullavere", "49211")
    p.village("Ronivere", "49217")
    p.village("Vanavälja", "49222")
    p.village("Praaklima", "49227")
    p.village("Varbevere", "49223")
    p.village("Änkküla", "49225")
    p.village("Kaarepere", "49201")
    p.village("Vaidavere", "49221")
    p.village("Luua", "49203")
    p.village("Rahivere", "49216")
    p.village("Toovere", "49220")
    p.village("Nava", "49212")
    p.village("Kivimäe", "49209")
    p.village("Kassivere", "49208")
    p.village("Raadivere", "49228")

    p.municipality("Puurmani", "")
    p.village("Tammiku", "49012")
    p.village("Härjanurme", "49003")
    p.village("Pikknurme", "49009")
    p.village("Jõune", "49004")
    p.village("Jüriküla", "49005")
    p.village("Kirikuvalla", "49006")
    p.village("Altnurga", "49002")
    p.village("Tõrve", "49013")
    p.village("Saduküla", "49011")
    p.village("Kursi", "49007")
    p.village("Laasme", "49008")
    p.village("Pööra", "49010")

    p.municipality("Saare", "")
    p.village("Voore", "")
    p.village("Koseveski", "")
    p.village("Sirguvere", "49317")
    p.village("Vassevere", "49321")
    p.village("Putu", "49313")
    p.village("Pedassaare", "49312")
    p.village("Odivere", "49311")
    p.village("Vanassaare", "49320")
    p.village("Ruskavere", "49315")
    p.village("Saarjärve", "49316")
    p.village("Nautrasi", "49310")
    p.village("Kiisli", "49306")
    p.village("Kallivere", "49305")
    p.village("Halliku", "49303")
    p.village("Maardla", "49309")
    p.village("Veia", "49322")
    p.village("Tarakvere", "49318")
    p.village("Pällu", "49314")
    p.village("Levala", "49308")
    p.village("Jaama", "49304")
    p.village("Kääpa", "49323")
    p.village("Tuulavere", "49319")

    p.municipality("Kasepää", "")
    p.village("Tiheda", "")
    p.village("Raja", "")
    p.village("Kükita", "")
    p.village("Metsaküla", "49505")
    p.village("Omedu", "49507")
    p.village("Nõmme", "49506")
    p.village("Kaasiku", "49502")

    p.municipality("Pajusi", "")
    p.village("Vägari", "")
    p.village("Pisisaare", "")
    p.village("Kalana", "")
    p.village("Lahavere", "")
    p.village("Tapiku", "48218")
    p.village("Kõpu", "48208")
    p.village("Loopre", "48211")
    p.village("Uuevälja", "48220")
    p.village("Tõivere", "48219")
    p.village("Kauru", "48206")
    p.village("Nurga", "48215")
    p.village("Aidu", "48202")
    p.village("Mõisaküla", "48213")
    p.village("Kõrkküla", "48209")
    p.village("Väljataguse", "48223")
    p.village("Kose", "48207")
    p.village("Arisvere", "48203")
    p.village("Kaave", "48204")
    p.village("Vorsti", "48221")
    p.village("Luige", "48212")
    p.village("Mõrtsi", "48214")
    p.village("Sopimetsa", "48217")

    p.municipality("Pala", "")
    p.village("Kodavere", "49407")
    p.village("Haavakivi", "49404")
    p.village("Lümati", "49425")
    p.village("Kokanurga", "49408")
    p.village("Nõva", "49411")
    p.village("Sassukvere", "49418")
    p.village("Kadrina", "49405")
    p.village("Sõõru", "49419")
    p.village("Sääritsa", "49420")
    p.village("Vea", "49422")
    p.village("Ranna", "49417")
    p.village("Perametsa", "49412")
    p.village("Raatvere", "49416")
    p.village("Äteniidi", "49423")
    p.village("Tagumaa", "49421")
    p.village("Kirtsi", "49406")
    p.village("Piibumäe", "49413")
    p.village("Piirivarbe", "49414")
    p.village("Moku", "49410")
    p.village("Assikvere", "49403")
    p.village("Metsanurga", "49409")
    p.village("Punikvere", "49415")

    p.municipality("Vägeva", "")

