# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Valga (county)
    p.county("Valga", "")
    p.town("Valga", "")
    p.town("Tõrva", "")
    p.town("Otepää", "")
    p.village("Nüpli", "")
    p.village("Sihva", "")
    p.village("Pühajärve", "")
    p.village("Vidrike", "67304")
    p.village("Pedajamäe", "67417")
    p.village("Tõutsi", "67303")
    p.village("Kääriku", "67309")
    p.village("Mägestiku", "67310")
    p.village("Pilkuse", "67416")
    p.village("Kastolatsi", "67410")
    p.village("Truuta", "67302")
    p.village("Kaurutootsi", "67307")
    p.village("Raudsepa", "67415")
    p.village("Arula", "67411")
    p.village("Mäha", "67409")
    p.village("Kassiratta", "67306")
    p.village("Koigu", "67308")
    p.village("Vana-Otepää", "67418")
    p.village("Märdi", "67311")
    p.village("Ilmjärve", "67305")

    p.municipality("Puka", "")
    p.village("Rebaste", "67216")
    p.village("Aakre", "67212")
    p.village("Palamuste", "67213")
    p.village("Pühaste", "67215")
    p.village("Pedaste", "67214")
    p.village("Põru", "67210")
    p.village("Prange", "67209")
    p.village("Purtsi", "68709")
    p.village("Meegaste", "67207")
    p.village("Kolli", "67204")
    p.village("Kibena", "67203")
    p.village("Vaardi", "68229")
    p.village("Kuigatsi", "68222")
    p.village("Kähri", "67206")
    p.village("Plika", "67208")
    p.village("Soontaga", "68617")
    p.village("Ruuna", "67211")
    p.village("Komsi", "67205")

    p.municipality("Õru", "")
    p.village("Õlatu", "67108")
    p.village("Õruste", "67111")
    p.village("Priipalu", "67102")
    p.village("Mustumetsa", "67106")
    p.village("Killinge", "67103")
    p.village("Lota", "67105")
    p.village("Kiviküla", "67104")
    p.village("Uniküla", "67107")

    p.municipality("Tõlliste", "")
    p.smallborough("Tsirguliina", "")
    p.village("Sooru", "")
    p.smallborough("Laatre", "")
    p.village("Jaanikese", "")
    p.village("Tagula", "")
    p.village("Vilaski", "68311")
    p.village("Rampe", "68310")
    p.village("Muhkva", "68309")
    p.village("Paju", "68217")
    p.village("Korijärve", "68313")
    p.village("Iigaste", "68308")
    p.village("Tinu", "68306")
    p.village("Supa", "68305")
    p.village("Väljaküla", "68312")

    p.municipality("Sangaste", "")
    p.village("Keeni", "")
    p.village("Lossiküla", "")
    p.village("Sarapuu", "67009")
    p.village("Vaalu", "68221")
    p.village("Lauküla", "67011")
    p.village("Tiidu", "67010")
    p.village("Kurevere", "67004")
    p.village("Mäeküla", "67003")
    p.village("Risttee", "67007")
    p.village("Mägiste", "68224")
    p.village("Restu", "67006")
    p.village("Ädu", "68219")
    p.village("Pringi", "68223")

    p.municipality("Karula", "")
    p.village("Raavitsa", "")
    p.village("Kaagjärve", "")
    p.village("Valtina", "")
    p.village("Lüllemäe", "")
    p.village("Koobassaare", "68111")
    p.village("Kirbu", "68107")
    p.village("Väheru", "68105")
    p.village("Pikkjärve", "68110")
    p.village("Rebasemõisa", "68113")
    p.village("Pugritsa", "68104")
    p.village("Londi", "68103")
    p.village("Käärikmäe", "68108")
    p.village("Lusti", "68109")

    p.municipality("Helme", "")
    p.village("Taagepera", "")
    p.village("Karjatnurme", "68511")
    p.village("Koorküla", "68508")
    p.village("Linna", "68619")
    p.village("Kirikuküla", "68611")
    p.village("Jõgeveste", "68616")
    p.village("Möldre", "68612")
    p.village("Holdre", "68505")
    p.village("Pilpa", "68504")
    p.village("Roobe", "68614")
    p.village("Patküla", "68613")
    p.village("Ala", "68507")
    p.village("Kalme", "68618")
    p.village("Kähu", "68506")

    p.municipality("Taheva", "")
    p.village("Koikküla", "")
    p.village("Hargla", "")
    p.village("Lutsu", "68005")
    p.village("Lepa", "68004")
    p.village("Sooblase", "68011")
    p.village("Tõrvase", "68008")
    p.village("Tsirgumäe", "68012")
    p.village("Korkuna", "68009")
    p.village("Koiva", "68006")
    p.village("Kalliküla", "68007")
    p.village("Laanemetsa", "68013")
    p.village("Ringiste", "68010")

    p.municipality("Põdrala", "")
    p.village("Leebiku", "")
    p.village("Riidaja", "")
    p.village("Pikasilla", "68715")
    p.village("Liva", "68706")
    p.village("Rulli", "68615")
    p.village("Uralaane", "68712")
    p.village("Lõve", "68707")
    p.village("Kungi", "68705")
    p.village("Karu", "68703")
    p.village("Vanamõisa", "68713")
    p.village("Kaubi", "68704")
    p.village("Pori", "68708")
    p.village("Voorbahi", "68714")
    p.village("Reti", "68710")

    p.municipality("Palupera", "")
    p.village("Hellenurme", "")
    p.village("Nõuni", "")
    p.village("Mäelooga", "67510")
    p.village("Atra", "67508")
    p.village("Räbi", "67503")
    p.village("Urmi", "67513")
    p.village("Päidla", "67506")
    p.village("Miti", "67509")
    p.village("Pastaku", "67512")
    p.village("Makita", "67516")
    p.village("Astuvere", "67507")
    p.village("Neeruti", "67505")
    p.village("Lutike", "67504")

    p.municipality("Hummuli", "")
    p.village("Piiri", "68405")
    p.village("Ransi", "68407")
    p.village("Kulli", "68404")
    p.village("Aitsra", "68402")
    p.village("Jeti", "68513")
    p.village("Soe", "68408")
    p.village("Puide", "68411")
    p.village("Alamõisa", "68403")


