# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Hiiu (county)
    p.county("Hiiu", "")
    p.town("Kärdla", "")
    p.municipality("Käina", "")
    p.village("Nõmme", "")
    p.village("Selja", "")
    p.village("Putkaste", "")
    p.village("Lelu", "")
    p.village("Ligema", "")
    p.village("Ühtri", "")
    p.village("Niidiküla", "92131")
    p.village("Kaigutsi", "92164")
    p.village("Ristivälja", "92135")
    p.village("Nasva", "92130")
    p.village("Mäeküla", "92116")
    p.village("Vaemla", "92137")
    p.village("Mäeltse", "92129")
    p.village("Orjaku", "")
    p.village("Kolga", "92126")
    p.village("Taterma", "92174")
    p.village("Kogri", "92125")
    p.village("Moka", "92128")
    p.village("Aadma", "92161")
    p.village("Taguküla", "92112")
    p.village("Jõeküla", "92118")
    p.village("Kuriste", "92171")
    p.village("Utu", "92136")
    p.village("Kaasiku", "92123")
    p.village("Esiküla", "92113")
    p.village("Laheküla", "92115")
    p.village("Luguse", "92127")
    p.village("Kleemu", "92124")
    p.village("Kassari", "92111")
    p.village("Villemi", "92138")
    p.village("Männamaa", "92102")
    p.village("Pärnselja", "92162")
    p.village("Nõmmerga", "92133")
    p.village("Allika", "92122")

    p.municipality("Kõrgessaare", "")
    p.village("Tahkuna", "")
    p.village("Lauka", "")
    p.village("Ülendi", "92229")
    p.village("Risti", "92224")
    p.village("Metsaküla", "92249")
    p.village("Kidaste", "92216")
    p.village("Kiduspe", "92234")
    p.village("Hüti", "92243")
    p.village("Heigi", "92241")
    p.village("Kopa", "92255")
    p.village("Laasi", "92231")
    p.village("Poama", "92259")
    p.village("Kodeste", "92217")
    p.village("Mangu", "92220")
    p.village("Mudaste", "92222")
    p.village("Hirmuste", "92228")
    p.village("Kalana", "92230")
    p.village("Mardihansu", "92256")
    p.village("Ogandi", "92223")
    p.village("Vilima", "92237")
    p.village("Sülluste", "92252")
    p.village("Puski", "92260")
    p.village("Lilbi", "92248")
    p.village("Koidma", "92218")
    p.village("Kurisu", "")
    p.village("Pihla", "92264")
    p.village("Kaleste", "92232")
    p.village("Kiivera", "92254")
    p.village("Heistesoo", "92270")
    p.village("Kauste", "92215")
    p.village("Reigi", "92265")
    p.village("Sigala", "92213")
    p.village("Tiharu", "92269")
    p.village("Palli", "92258")
    p.village("Lehtma", "92219")
    p.village("Isabella", "92244")
    p.village("Napi", "92250")
    p.village("Mägipe", "92233")
    p.village("Villamaa", "92261")
    p.village("Meelste", "92221")
    p.village("Viita", "92227")
    p.village("Ojaküla", "92235")
    p.village("Viitasoo", "92238")
    p.village("Malvaste", "92211")
    p.village("Suurepsi", "92236")
    p.village("Heiste", "92242")
    p.village("Suureranna", "92225")
    p.village("Leigri", "92247")
    p.village("Luidja", "92202")
    p.village("Rootsi", "92266")
    p.village("Jõeranna", "92263")
    p.village("Paope", "92267")
    p.village("Kõpu", "92212")
    p.village("Jõesuu", "92253")
    p.village("Kanapeeksi", "92214")
    p.village("Otste", "92251")
    p.village("Tammistu", "92268")

    p.municipality("Pühalepa", "")
    p.village("Hausma", "")
    p.village("Suuremõisa", "")
    p.village("Kuri", "")
    p.village("Loja", "")
    p.village("Tareste", "")
    p.village("Hiiessaare", "")
    p.village("Salinõmme", "92317")
    p.village("Sarve", "92322")
    p.village("Lõbembe", "92340")
    p.village("Reikama", "92344")
    p.village("Harju", "")
    p.village("Hagaste", "92332")
    p.village("Kerema", "92315")
    p.village("Lõpe", "92341")
    p.village("Määvli", "92362")
    p.village("Suuresadama", "92346")
    p.village("Partsi", "92342")
    p.village("Soonlepa", "92323")
    p.village("Tubala", "92311")
    p.village("Viilupi", "92320")
    p.village("Valipe", "92319")
    p.village("Värssu", "92349")
    p.village("Kalgi", "92314")
    p.village("Leerimetsa", "92361")
    p.village("Pilpaküla", "92368")
    p.village("Ala", "92331")
    p.village("Prählamäe", "92364")
    p.village("Vilivalla", "92367")
    p.village("Linnumäe", "92422")
    p.village("Sakla", "92345")
    p.village("Vahtrepa", "92318")
    p.village("Undama", "92366")
    p.village("Kõlunõmme", "92338")
    p.village("Aruküla", "92321")
    p.village("Sääre", "92347")
    p.village("Hilleste", "92313")
    p.village("Nõmba", "92363")
    p.village("Hellamaa", "92334")
    p.village("Paluküla", "92420")
    p.village("Palade", "92301")
    p.village("Kukka", "92336")
    p.village("Puliste", "92343")
    p.village("Tempa", "92348")
    p.village("Heltermaa", "92312")
    p.village("Tammela", "92365")

    p.municipality("Emmaste", "")
    p.village("Kaderna", "92045")
    p.village("Reheselja", "92019")
    p.village("Lepiku", "92014")
    p.village("Lassi", "92051")
    p.village("Hindu", "92012")
    p.village("Jausa", "92003")
    p.village("Õngu", "92059")
    p.village("Valgu", "92011")
    p.village("Muda", "92029")
    p.village("Haldreka", "92043")
    p.village("Kabuna", "92041")
    p.village("Metsapere", "92053")
    p.village("Külaküla", "92049")
    p.village("Tilga", "92024")
    p.village("Tärkma", "92026")
    p.village("Sõru", "92023")
    p.village("Külama", "92021")
    p.village("Sinima", "92058")
    p.village("Pärna", "92017")
    p.village("Prassi", "92016")
    p.village("Nurste", "92002")
    p.village("Prähnu", "92056")
    p.village("Kuusiku", "92048")
    p.village("Mänspe", "92054")
    p.village("Viiri", "92027")
    p.village("Kitsa", "92046")
    p.village("Leisu", "92052")
    p.village("Tohvri", "92025")
    p.village("Rannaküla", "92018")
    p.village("Metsalauka", "92015")
    p.village("Ole", "92055")
    p.village("Ulja", "92030")
    p.village("Laartsa", "92050")
    p.village("Härma", "92044")
    p.village("Kõmmusselja", "92013")
    p.village("Riidaküla", "92020")
    p.village("Haldi", "92042")
    p.village("Sepaste", "92022")
    p.village("Vanamõisa", "92060")


